//*****************************************
// AVR ATmega644P Geiger Counter 
// CPU Clock:8MHz,16NHz,18.432MHz or 20MHz(Compile Option)
// File Name:AVR_ATmega644_Geiger.c
// KCK[JE^[@p
//   iq[Yf[^@is`fgpȂAȂAwIV[^(8MHz)Aɂj
//   i`FbN͂rohdmj
//
//@kbc͂PQWUShbgOtBbNW[gp
//    TG12864E-01XWBV or SG12864ASLB-GB-R01
//
//  PA0: LCD-R/W*
//  PA1: LCD-CS2
//  PA2: LCD-CS1
//  PA3: LCD-E
//  PA4: LCD-D/I*
//  PA5: LCD-RST*
//  PA6(ADC6): Batter Monitor Max. about 1V (1V = 5V)
//  PA7(ADC7): High Volt Monitor Max. about 1V (1V = 1000V)
//
//  PB0: LCD-DB0
//  PB1: LCD-DB1
//  PB2: LCD-Back Light(H=ON, L=OFF)
//  PB3: RED LED(H=ON, L=OFF)
//  PB4(OC0B): Sperker Out(4kHz Signal)
//  PB5(MOSI): PS6-4pin
//  PB6(MISO): PS6-1pin
//  PB7(SCK) : PS6-3pin
//
//  PC0(SCL): TWI-SCL
//  PC1(SDA): TWI-SDA
//  PC2: LCD-DB2
//  PC3: LCD-DB3
//  PC4: LCD-DB4
//  PC5: LCD-DB5
//  PC6: LCD-DB6
//  PC7: LCD-DB7
//
//  PD0(RXD0): Serial Rxd
//  PD1(TXD0): Serial Txd
//  PD2(INT0): Pulse In from RTC Square Wave Signal(1Hz,4kHz,8kHz,32kHz)
//  PD3(INT1): Geiger Myuler Pulse(Active Low)
//  PD4(OC1B): Pulse Out for High Volt Generator
//  PD5: Tact Switch(Blue)
//  PD6: Tact Switch(Yellow)
//  PD7: Tact Switch(White)
//
//
//  C:\WinAVR-20100110\doc\avr-libc\avr-libc-user-manual.pdf ɊeCN[ht@C̐
//
//  2011/09/02 New  Taishi ATmega644P(J308)
//  2011/10/22 Modify for LND712 by  Taishi
//  2011/10/28 Modify for SBM-20 by  Taishi
//  2011/11/08 Modify for LND712 by  Taishi(Ver 1.02)
//  2011/11/12 Modify for SBM-20 by  Taishi(Ver 1.02)
//  2011/11/12 Modify for J-308  by  Taishi(Ver 1.03)
//  2011/11/24 Modify for All Model  Taishi
//  2011/12/12 Modify for All Model  Taishi(Ver 1.03A) 
//             v킹̍ŏ̌NPǑɂB
//             ۑf[^MAguݒlOɂȂsCB
//             iROW̎Ak|rvAq|rv~߁AxAvɂB
//             gp̕f[^̍폜BiRgAEgj
//  2012/02/18 Modify for All Model  Taishi(Ver 1.04) 
//             肕r^~߁APԂ̈ړϒlɕύXB
//*****************************************

#include	<avr/interrupt.h>
#include	<avr/io.h>
#include	<avr/eeprom.h>
#include	<avr/sleep.h>
#include	<avr/pgmspace.h>

#include	"AVR_ATmega644_Geiger.h"
#include	"Serial.h"
#include	"Comm1.h"
#include	"Comm2.h"
#include	"LCD.h"
#include	"Display.h"
#include	"Setting.h"
#include	"EEPROM.h"
#include	"Utility.h"
#include	"Timer.h"
#include	"Ad_conv.h"
#include	"Pulse.h"
#include	"Rtc.h"
#include	"Seeprom.h"
#include	"Graph.h"
#include	"Mega_Twi.h"

#ifdef		ONE_BATTERY
unsigned char	str_title_3[] PROGMEM = {"for One Battery"};			// ^Cg|R
#endif

unsigned char	str_title_1[] PROGMEM = {STR_TITLE1};					// ^Cg|P

unsigned char	str_title_2[] PROGMEM = {"  Ver 1.04 "};				// ^Cg|Q
unsigned char	str_date[] PROGMEM = {__DATE__};						// 쐬@N
unsigned char	str_time[] PROGMEM = {__TIME__};						// 쐬@
unsigned char	str_crlf[] PROGMEM = {"\r\n"};							// CR + LF

#ifdef	CHECK_SW_LED_SERIAL
unsigned char	str_echo_check[] PROGMEM = {"Echo Rec + 1"};			// "Echo Rec + 1"
unsigned char	str_echo_E[] PROGMEM = {" Rec=\'E\' --> END"};			// " Rec=E --> END"
unsigned char	str_echo_end[] PROGMEM = {"Echo Check End"};			// "Echo Check End"
#endif	//CHECK_SW_LED_SERIAL

#ifdef	CHECK_LCD
unsigned char	str_lcd_chk_start[] PROGMEM = {"LCD check start"};		// "LCD check start"
#endif	//CHECK_LCD


unsigned char	str_cpm[] PROGMEM          = {"cpm"};				// "cpm"
unsigned char	str_cph[] PROGMEM          = {"cph"};				// "cph"
unsigned char	str_cpd[] PROGMEM          = {"cpd"};				// "cpd"
unsigned char	str_migi[] PROGMEM         = {"-"};					// ">"
unsigned char	str_save_data[] PROGMEM    = {"No       uSv/h"};	// "No  cph  uSv/h"
unsigned char	str_save_data_NO_RTC[] PROGMEM    = {"No          uSv/h"};	// "No  cph  uSv/h"
unsigned char	str_5minus[] PROGMEM       = {"-----"};				// "-----"
unsigned char	str_no_data[] PROGMEM      = {"Non Data !!"};		// "Non Data !!"
unsigned char	str_hv_monitor[] PROGMEM   = {"HV Monitor"};		// "HV Monitor"
unsigned char	str_buz_enable[] PROGMEM   = {"Buzzer Enable"};		// "Buzzer Enable"
unsigned char	str_buz_disable[] PROGMEM  = {"Buzzer Disable"};	// "Buzzer Disable"
unsigned char	str_data_delete[] PROGMEM  = {"Data Delete ?"};		// "Data Delete ?"
#ifdef	J_308
unsigned char	str_era_y_n[] PROGMEM      = {"N:Yellow Y:White"};	// "Y:White N:Yellow"
#else	// J_308
unsigned char	str_era_y_n[] PROGMEM      = {"N:L-SW Y:R-SW"};		// "Y:R-SW N:L-SW"
#endif	// J_308
unsigned char	str_question[] PROGMEM     = {"?"};					// "?"
unsigned char	str_space10[] PROGMEM      = {"          "};		// "          "
unsigned char	str_volt[] PROGMEM         = {"V"};					// "V"
unsigned char	str_adj[] PROGMEM          = {"Adj"};				// "Adj"
unsigned char	str_sel[] PROGMEM          = {"Sel"};				// "Sel"
unsigned char	str_hv_moni[] PROGMEM      = {"HV-Moni"};			// "HV-Moni"
unsigned char	str_save_exit[] PROGMEM    = {"Save&Exit"};			// "Save&Exit
unsigned char	str_save_next[] PROGMEM    = {"Save&Next"};			// "Save&Next
unsigned char	str_ten8[] PROGMEM         = {"........"};			// "."

unsigned char	str_hv_out[] PROGMEM       = {"HV-Out"};			// "HV-Out"
unsigned char	str_hv_volt[] PROGMEM      = {"HV-Volt"};			// "HV-Volt"
unsigned char	str_cpm_to_uSv[] PROGMEM   = {"cpm->uSv"};			// "com->uSv"
unsigned char	str_per_h[] PROGMEM        = {"/h"};				// "/h"
unsigned char	str_uSv[] PROGMEM          = {"uSv"};				// "uSv"
unsigned char	str_span[] PROGMEM         = {"Span"};				// "Span"
unsigned char	str_offset[] PROGMEM       = {"Ofset"};				// "Ofset"

unsigned char	str_save_select1[] PROGMEM = {"Sel cpm,cph or cpd ?"};	// "Sel cpm,cph or cpd ?"
unsigned char	str_cr_lf[] PROGMEM        = {"\r\n"};				// CR+LF
unsigned char	str_5asta[] PROGMEM        = {"*****"};				// "*****"
unsigned char	str_average[] PROGMEM      = {"Ave. "};				// "Ave. "

unsigned char	str_zero[] PROGMEM         = {"0"};					// "0"
unsigned char	str_dive[] PROGMEM         = {"/"};					// "/"
unsigned char	str_minus[] PROGMEM        = {"-"};					// "-"
unsigned char	str_asta[] PROGMEM         = {"*"};					// "*"
unsigned char	str_plus[] PROGMEM         = {"+"};					// "+"

unsigned char	str_hi[] PROGMEM           = {"Hi"};				// "Hi"
unsigned char	str_lo[] PROGMEM           = {"Lo"};				// "Lo"
unsigned char	str_mon_spn[] PROGMEM      = {"MON_SPN"};			// "MON_SPN"
unsigned char	str_mon_ofs[] PROGMEM      = {"MON_OFS"};			// "MON_OFS"
unsigned char	str_d_time[] PROGMEM       = {"Set Time"};			// "Set Time"

unsigned char	str_back_light_off[] PROGMEM  = {"Back Light OFF "};	// "Back Light OFF "
unsigned char	str_back_light_auto[] PROGMEM = {"Back Light AUTO"};	// "Back Light AUTO"
unsigned char	str_back_light_on[] PROGMEM   = {"Back Light ON  "};	// "Back Light ON  "
#ifdef	J_308
unsigned char	str_yl_nr[] PROGMEM           = {"Yes:Yellow No:White"};	// "Yes:WYellow No:White"
#else	// J_308
unsigned char	str_yl_nr[] PROGMEM           = {"Yes:L-SW No:R-SW"};	// "Y:L-SW N:R-SW"
#endif	// J_308
unsigned char	str_99999999[] PROGMEM     = {"99999999"};			// "99999999"
unsigned char	str_bat[] PROGMEM          = {"Bat"};				// "Bat"
unsigned char	str_sec[] PROGMEM          = {"sec"};				// "sec"
#ifdef	J_308
unsigned char	str_clock_adjust[] PROGMEM = {"White :Clock Adjust"};	// "White Clock Adjust"
unsigned char	str_escape_this[] PROGMEM  = {"Yellow:Escape This "};	// "Yellow Escape This"
#else	// J_308
unsigned char	str_clock_adjust[] PROGMEM = {" R-SW Clock Adjust "};	// "R-SW Clock Adjust"
unsigned char	str_escape_this[] PROGMEM  = {" L-SW Escape This "};	// "L-SW Escape This"
#endif	// J_308
unsigned char	str_done[] PROGMEM         = {"Done"};				// "Done"
unsigned char	str_display_end[] PROGMEM  = {"Display End ?"};		// "Display End ?"
unsigned char	str_save_data_delete[] PROGMEM = {"Delete Save Data"};	// "Clear Save Data"
unsigned char	str_display_save_data[] PROGMEM = {"Display Save Data"};	// "Display Save Data"
unsigned char	str_save_data_transmit[] PROGMEM = {"Transmit Save Data"};	// "Transmit Save Data"
unsigned char	str_save_data_graph[] PROGMEM = {"Graph Save Data"};		// "Graph Save Data"
unsigned char	str_save_sel_proc[] PROGMEM = {"Select Process"};	// "Select Process"
unsigned char	str_for_save_date[] PROGMEM = {" for Save Data"};	// " for Save Data"
unsigned char	str_disp_vul[] PROGMEM     = {"Display Value"};		// "Display Value"
unsigned char	str_disp_grh[] PROGMEM     = {"Display Graph"};		// "Display Graph"
unsigned char	str_transmit[] PROGMEM     = {"Transmit"};			// "Transmit"
unsigned char	str_delete[] PROGMEM       = {"Delete"};			// "Delete"
unsigned char	str_exit[] PROGMEM         = {"Exit"};				// "Exit
unsigned char	str_next[] PROGMEM         = {"Next"};				// "Next
unsigned char	str_make_date[] PROGMEM    = {"Make Date:"};		// "Make Date
unsigned char	str_60s[] PROGMEM          = {"60s"};				// "60s
unsigned char	str_10m[] PROGMEM          = {"10m"};				// "10m
unsigned char	str_18m[] PROGMEM          = {"18m"};				// "18m
unsigned char	str_34m[] PROGMEM          = {"34m"};				// "34m
unsigned char	str_62m[] PROGMEM          = {"62m"};				// "62m

unsigned char	buz_on;							// uU[gp 1:gpA 0:sgp
unsigned char	hv_uSv_disp;					// gudAr\ 2:uSv+uSv, 1:HV+cpm, 0:cph+cpm
unsigned int	old_count_minute;				// OPԖ̃JEg
unsigned char	in_hv_adja;						// 0:guLĂA1:guLĂȂi킹ݒj
unsigned char	back_light_mode;				// obNCg̏^_[hiOFneeAPF`tsnAQFnm)
unsigned char	tim_1minute;					// 
unsigned char	tim_1hour;						// 

unsigned long	count_day[N_of_DAY_DATA];
unsigned long	count_hour[N_of_HOUR_DATA];
unsigned int	count_minute[N_of_MINUTE_DATA];
unsigned int	sec_data[N_of_SEC_DATA];		// PbƂ̃f[^
unsigned char	cpd_data_pos;
unsigned char	cph_data_pos;
unsigned char	cpm_data_pos;
unsigned char	sec_data_pos;
unsigned int	cpm_to_uSv_spn;					// cpm_to_uSv_spn Zl̂PO{(1000:100.0)
unsigned int	cpm_to_uSv_ofs;					// cpm_to_uSv_ofs ZItZbg(JEgl炱̒l)
unsigned char	non_rtc = 0;
unsigned char	non_seep = 0;
unsigned char	tim_1s_a;						// PbPʃ^C}[
unsigned char	tim_1s_back_light;				// obNCgpPbPʃ^C}[


//*****************************************
// kbcG[
//  PB3: RED LED(H=ON, L=OFF)
//*****************************************
void	lcd_error(void)
{
#ifdef	_SIMURATION_					// V~[V̎
		;
#else	//_SIMURATION_

	cli();

	DDRB |= (1 << DDB3);											// Port-B Bit3 : Output
	for(;;){
		PORTB |=  (1 << PB3);
		delay_ms(100);												// 200mS Delay
		PORTB &= ~(1 << PB3);
		delay_ms(200);												// 200mS Delay
	}

#endif	//_SIMURATION_
}

#ifdef		TWI_DEBUG_ENABLE
//*****************************************
// svhM̏ԕ\
//   y:\ʒuixj0--7
//         ̍sRsɕ\
//  ߂̒lU܂őkf[^\
//*****************************************
void	disp_twi_transmit_data(unsigned char y)
{
	unsigned char	twidata[16];
	unsigned char	i;

	disp_lcd_G( 0, y+0, (unsigned char *)"WD ");	// display Dot Matrix LCD
	twi_debug_Load_WriteData(&twidata[0]);
	for(i=0;i<6;i++){
		wtod_02x((char *)disp_moji, twidata[i]);	// svhőf[^
		disp_lcd_G( i*3+3, y+0, &disp_moji[0]);		// display Dot Matrix LCD
	}

	disp_lcd_G( 0, y+1, (unsigned char *)"WS ");	// display Dot Matrix LCD
	twi_debug_Load_WStatData(&twidata[0]);
	for(i=0;i<6;i++){
		wtod_02x((char *)disp_moji, twidata[i]);	// svhő̏
		disp_lcd_G( i*3+3, y+1, &disp_moji[0]);		// display Dot Matrix LCD
	}

	disp_lcd_G( 0, y+2, (unsigned char *)"RD ");	// display Dot Matrix LCD
	twi_debug_Load_ReadData(&twidata[0]);
	for(i=0;i<6;i++){
		wtod_02x((char *)disp_moji, twidata[i]);	// svhœǂ񂾃f[^
		disp_lcd_G( i*3+3, y+2, &disp_moji[0]);		// display Dot Matrix LCD
	}

}
#endif		//TWI_DEBUG_ENABLE
//*****************************************
// qsbG[
//  PB3: RED LED(H=ON, L=OFF)
//  ʏ͂ŏI邪A̃XCb`ꍇ͔
//*****************************************
void	rtc_error(unsigned char d)
{
#ifdef	_SIMURATION_					// V~[V̎
		;
#else	//_SIMURATION_
 #ifdef		TWI_DEBUG_ENABLE
	unsigned char	uc0;
	unsigned char	uc1;
	unsigned char	uc2;
 #endif		//TWI_DEBUG_ENABLE

	disp_lcd_G( 0, 0,(unsigned char *)"rtc_init Error !!");	// \
	wtod_2u((char *)disp_moji, d);							// G[
	disp_lcd_G( 0, 1, &disp_moji[0]);						// display Dot Matrix LCD Down Side
	wtod_02x((char *)disp_moji, gTwi_status);				// G[
	disp_lcd_G( 5, 1, &disp_moji[0]);						// display Dot Matrix LCD Down Side
	disp_one_char_lcd_G( 7, 1, 'h');						// 'h'

	DDRB |= (1 << DDB3);									// Port-B Bit3 : Output
 #ifdef		TWI_DEBUG_ENABLE
	disp_twi_transmit_data(3);								// svhM̏ԕ\

	cli();
	uc0 = 0;
	uc1 = 0;
	uc2 = 0;

	for(;;){
		uc0 = (~PIND & (SW_LEFT | SW_RIGHT));
		PORTB |=  (1 << PB3);
		delay_ms(100);												// 200mS Delay
		uc1 = (~PIND & (SW_LEFT | SW_RIGHT));
		PORTB &= ~(1 << PB3);
		delay_ms(500);												// 200mS Delay
		uc2 = (~PIND & (SW_LEFT | SW_RIGHT));
		if( (uc0 == (SW_LEFT | SW_RIGHT)) && (uc2 == (SW_LEFT | SW_RIGHT)) && (uc2 == (SW_LEFT | SW_RIGHT)) ){		// ̃XCb`ꑱ
			non_rtc = 1;
			break;
		}
	}
 #else	//TWI_DEBUG_ENABLE
	non_rtc = 1;
	delay_ms(2000);
 #endif		//TWI_DEBUG_ENABLE

	DDRB &= ~(1 << DDB3);											// Port-B Bit3 : Output

#endif	//_SIMURATION_
}

//*****************************************
// rdddoG[isvhANZXj
//  PB3: RED LED(H=ON, L=OFF)
//  ʏ͂ŏI邪A̃XCb`ꍇ͔
//*****************************************
void	seep_error1(unsigned char d)
{
#ifdef	_SIMURATION_					// V~[V̎
		;
#else	//_SIMURATION_
 #ifdef		TWI_DEBUG_ENABLE
	unsigned char	uc0;
	unsigned char	uc1;
	unsigned char	uc2;
 #endif		//TWI_DEBUG_ENABLE

	disp_lcd_G( 0, 0,(unsigned char *)"seep.(TWI) Error !!");	// \
	wtod_2u((char *)disp_moji, d);							// G[
	disp_lcd_G( 0, 1, &disp_moji[0]);						// display Dot Matrix LCD Down Side
	wtod_02x((char *)disp_moji, gTwi_status);				// G[
	disp_lcd_G( 5, 1, &disp_moji[0]);						// display Dot Matrix LCD Down Side
	disp_one_char_lcd_G( 7, 1, 'h');						// 'h'

	DDRB |= (1 << DDB3);									// Port-B Bit3 : Output
 #ifdef		TWI_DEBUG_ENABLE
	disp_twi_transmit_data(3);								// svhM̏ԕ\


	cli();
	uc0 = 0;
	uc1 = 0;
	uc2 = 0;

	for(;;){
		uc0 = (~PIND & (SW_LEFT | SW_RIGHT));
		PORTB |=  (1 << PB3);
		delay_ms(100);												// 200mS Delay
		uc1 = (~PIND & (SW_LEFT | SW_RIGHT));
		PORTB &= ~(1 << PB3);
		delay_ms(500);												// 200mS Delay
		uc2 = (~PIND & (SW_LEFT | SW_RIGHT));
		if( (uc0 == (SW_LEFT | SW_RIGHT)) && (uc2 == (SW_LEFT | SW_RIGHT)) && (uc2 == (SW_LEFT | SW_RIGHT)) ){		// ̃XCb`ꑱ
			non_seep = 1;
			break;
		}
	}
 #else	//TWI_DEBUG_ENABLE
	non_seep = 1;
	delay_ms(2000);
 #endif		//TWI_DEBUG_ENABLE

	DDRB &= ~(1 << DDB3);											// Port-B Bit3 : Output

#endif	//_SIMURATION_
}

//*****************************************
// VAddoqnlG[
//  PB3: RED LED(H=ON, L=OFF)
//  ʏ͂ŏI邪A̃XCb`ꍇ͔
//*****************************************
void	seep_error2(unsigned char dw, unsigned char dr)
{
#ifdef	_SIMURATION_					// V~[V̎
		;
#else	//_SIMURATION_
 #ifdef		TWI_DEBUG_ENABLE
	unsigned char	uc0;
	unsigned char	uc1;
	unsigned char	uc2;
 #endif		//TWI_DEBUG_ENABLE

	disp_lcd_G( 0, 0,(unsigned char *)"Seeprom Error !!");	// \
	disp_lcd_G( 0, 1,(unsigned char *)"Writ ");				// \
	wtod_02x((char *)disp_moji, dw);						// G[
	disp_lcd_G( 5, 1, &disp_moji[0]);						// display Dot Matrix LCD Down Side
	disp_lcd_G( 7, 1,(unsigned char *)"h !=");				// \
	wtod_02x((char *)disp_moji, dr);						// G[
	disp_lcd_G(12, 1, &disp_moji[0]);						// display Dot Matrix LCD Down Side
	disp_lcd_G(14, 1,(unsigned char *)"h Read");			// \

	DDRB |= (1 << DDB3);									// Port-B Bit3 : Output
 #ifdef		TWI_DEBUG_ENABLE

	uc0 = 0;
	uc1 = 0;
	uc2 = 0;

	for(;;){
		uc0 = (~PIND & (SW_LEFT | SW_RIGHT));
		PORTB |=  (1 << PB3);
		delay_ms(100);												// 100mS Delay
		uc1 = (~PIND & (SW_LEFT | SW_RIGHT));
		PORTB &= ~(1 << PB3);
		delay_ms(500);												// 100mS Delay
		uc2 = (~PIND & (SW_LEFT | SW_RIGHT));
		if( (uc0 == (SW_LEFT | SW_RIGHT)) && (uc2 == (SW_LEFT | SW_RIGHT)) && (uc2 == (SW_LEFT | SW_RIGHT)) ){		// ̃XCb`ꑱ
			non_rtc = 1;
			break;
		}
	}
 #else	//TWI_DEBUG_ENABLE
	non_seep = 1;
	delay_ms(2000);
 #endif		//TWI_DEBUG_ENABLE

	DDRB &= ~(1 << DDB3);											// Port-B Bit3 : Output

#endif	//_SIMURATION_
}

//*****************************************
// (unsigned char)
// uc0: mDO̒l
// uc1: mDP̒l
// uc2: mDQ̒l
// def: SĈĂ Cl
//*****************************************
unsigned char	tasuuketu_uc(unsigned char uc0, unsigned char uc1, unsigned char uc2, unsigned char def)
{
	unsigned char	uc;

	if(uc0 == uc1){
		uc = uc0;
	}else if(uc0 == uc2){
		uc = uc0;
	}else if(uc1 == uc2){
		uc = uc1;
	}else{
		uc = def;
	}

	return(uc);
}
//*****************************************
// obNCg[h̓ǂݏo
// @荞ݕs̏ԂŌĂ΂Ƃ
//*****************************************
void	load_back_light_mode(void)
{
	unsigned char	i;
	unsigned char	uc;
	unsigned char	uc_dim[3];

	for(i=0;i<3;i++){
		eeprom_busy_wait();
		uc_dim[i] = eeprom_read_byte(&eep_back_light_mode[i]);			// obNCg[h
	}
	uc = tasuuketu_uc(uc_dim[0], uc_dim[1], uc_dim[2], 1);				// 

	for(i=0;i<3;i++){
		if(uc != uc_dim[i]){
			eeprom_busy_wait();
			eeprom_write_byte(&eep_back_light_mode[i], uc);			// lɂ
		}
	}

	if(uc == 1){
		back_light_mode = 1;
	}else if(uc == 2){
		back_light_mode = 2;
	}else{
		back_light_mode = 0;
	}
}
//*****************************************
// obNCg[h̕ۑ
// @荞ݕs̏ԂŌĂ΂Ƃ
//*****************************************
void	save_back_light_mode(void)
{
	unsigned char	i;

	for(i=0;i<3;i++){
		eeprom_busy_wait();
		eeprom_write_byte(&eep_back_light_mode[i], back_light_mode);		// 
	}
	eeprom_busy_wait();
}
//*****************************************
// uU[nm^nee̓ǂݏo
// @荞ݕs̏ԂŌĂ΂Ƃ
//*****************************************
void	load_buz_on_off(void)
{
	unsigned char	i;
	unsigned char	uc;
	unsigned char	uc_dim[3];

	for(i=0;i<3;i++){
		eeprom_busy_wait();
		uc_dim[i] = eeprom_read_byte(&eep_buz_on[i]);				// uU[gp
	}
	uc = tasuuketu_uc(uc_dim[0], uc_dim[1], uc_dim[2], 0);				// 

	for(i=0;i<3;i++){
		if(uc != uc_dim[i]){
			eeprom_busy_wait();
			eeprom_write_byte(&eep_buz_on[i], uc);			// lɂ
		}
	}

	if(uc == 1){
		buz_on = 1;
	}else{
		buz_on = 0;
	}
}
//*****************************************
// uU[nm^nee̕ۑ
// @荞ݕs̏ԂŌĂ΂Ƃ
//*****************************************
void	save_buz_on_off(void)
{
	unsigned char	i;

	for(i=0;i<3;i++){
		eeprom_busy_wait();
		eeprom_write_byte(&eep_buz_on[i], buz_on);		// 
	}
}
//*****************************************
// f[^̕ۑiPƂ̃f[^j
// @荞݉̏ԂŌĂ΂Ƃ
//*****************************************
void	save_day_data(unsigned long ul)
{
	unsigned int	uc;

	eeprom_busy_wait();
	uc = eeprom_read_byte(&eep_cpd_write_pos);			// ۑʒu
	if(N_of_HOUR_DATA <= uc){
		uc = 0;
	}

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_dword(eep_day_data + uc, ul);			// f[^̕ۑ
	sei();												// 荞݉

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_dword(eep_day_time_data + uc, gDate_Time);	// Pf[^̕ۑ
	sei();												// 荞݉

	uc++;
	if(N_of_HOUR_DATA <= uc){
		uc = 0;
	}

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_byte(&eep_cpd_write_pos, uc);			// ̕ۑʒu
	sei();												// 荞݉
}
//*****************************************
// f[^̕ۑiPԂƂ̃f[^j
// @荞݉̏ԂŌĂ΂Ƃ
//*****************************************
void	save_hour_data(unsigned long ul)
{
	unsigned int	uc;

	eeprom_busy_wait();
	uc = eeprom_read_byte(&eep_cph_write_pos);			// ۑʒu
	if(N_of_HOUR_DATA <= uc){
		uc = 0;
	}

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_dword(eep_hour_data + uc, ul);			// f[^̕ۑ
	sei();												// 荞݉

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_dword(eep_hour_time_data + uc, gDate_Time);	// PԖf[^̕ۑ
	sei();												// 荞݉

	uc++;
	if(N_of_HOUR_DATA <= uc){
		uc = 0;
	}

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_byte(&eep_cph_write_pos, uc);			// ̕ۑʒu
	sei();												// 荞݉
}
//*****************************************
// Pf[^̕ۑ
// @荞݉̏ԂŌĂ΂Ƃ
//*****************************************
void	save_minute_data(unsigned int ui)
{
	unsigned int	uc;

	eeprom_busy_wait();
	uc = eeprom_read_byte(&eep_cpm_write_pos);			// ۑʒu
	if(N_of_MINUTE_DATA <= uc){
		uc = 0;
	}

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_word(eep_minute_data + uc, ui);		// Pf[^̕ۑ
	sei();												// 荞݉

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_dword(eep_minute_time_data + uc, gDate_Time);	// Pf[^̕ۑ
	sei();												// 荞݉

	uc++;
	if(N_of_MINUTE_DATA <= uc){
		uc = 0;
	}

	cli();												// 荞ݕs
	eeprom_busy_wait();
	eeprom_write_byte(&eep_cpm_write_pos, uc);			// ̕ۑʒu
	sei();												// 荞݉
}
//*****************************************
// Pf[^̑S
// @荞݉̏ԂŌĂ΂Ƃ
//*****************************************
void	delete_day_data(void)
{
	unsigned char	uc;

	cli();													// Öׁ@荞ݕs
	uc = 0xff;
	eeprom_busy_wait();
	eeprom_write_byte(&eep_cpd_write_pos, uc);				// ̕ۑʒu

	for(uc = 0; uc < N_of_EEP_DAY_DATA; uc++){
		eeprom_busy_wait();
		eeprom_write_dword(eep_day_data + uc, 0xffffffff);	// Pf[^̕ۑ
		eeprom_busy_wait();
		eeprom_write_dword(eep_day_time_data + uc, 0xffffffff);	// Pf[^̓
	}
}
//*****************************************
// PԖf[^̑S
// @荞݉̏ԂŌĂ΂Ƃ
//*****************************************
void	delete_hour_data(void)
{
	unsigned char	uc;

	cli();													// Öׁ@荞ݕs
	uc = 0xff;
	eeprom_busy_wait();
	eeprom_write_byte(&eep_cph_write_pos, uc);				// ̕ۑʒu

	for(uc = 0; uc < N_of_EEP_HOUR_DATA; uc++){
		eeprom_busy_wait();
		eeprom_write_dword(eep_hour_data + uc, 0xffffffff);	// PԖf[^̕ۑ
		eeprom_busy_wait();
		eeprom_write_dword(eep_hour_time_data + uc, 0xffffffff);	// PԖf[^̓
	}
}
//*****************************************
// Pf[^̑S
// @荞ݕs̏ԂŌĂ΂Ƃ
//*****************************************
void	delete_minute_data(void)
{
	unsigned char	uc;

	cli();													// Öׁ@荞ݕs
	uc = 0xff;
	eeprom_busy_wait();
	eeprom_write_byte(&eep_cpm_write_pos, uc);				// ̕ۑʒu

	for(uc = 0; uc < N_of_EEP_MINUTE_DATA; uc++){
		eeprom_busy_wait();
		eeprom_write_word(eep_minute_data + uc, 0xffff);	// PԖf[^̕ۑ
		eeprom_busy_wait();
		eeprom_write_dword(eep_minute_time_data + uc, 0xffffffff);	// PԖf[^̓
	}
}




// **********************************************************
// ******************** r^Zl ********************
// **********************************************************
//unsigned char	ave_data_pos = 0;			// xۑf[^̈ʒu
//unsigned int	ave_data[0x40];				// P̃f[^US
//*****************************************
// rZ\iPԂ̃JEgPԂ̃JEgɂj
//  F\ʒu(0-->15)
//  Fs\ʒu(0-->1)
//  FJEgli@́@j
//  QF1:PԒl@́@0:PԒl
//  QFPʕ\(uSv/h) 1:LA 0:
//*****************************************
void	disp_uSv_at_count(unsigned char x, unsigned char y, unsigned long cp, unsigned char minute_data, unsigned char unit_ari)
{
	unsigned long	ul;

	get_pgm_str(&str_space10[0]);							// vÖ̕("      ")擾
	disp_lcd_G(x,y,&disp_moji[9]);							// \
	if((cp == 0xffff)&&(minute_data == 1)){					// f[^
		get_pgm_str(&str_5minus[0]);						// vÖ̕("----")擾
		disp_lcd_G(x,y,&disp_moji[1]);					// \
	}else if(cp == 0xffffffff){								// f[^
		get_pgm_str(&str_5minus[0]);						// vÖ̕("----")擾
		disp_lcd_G(x,y,&disp_moji[1]);					// \
	}else{
		if(minute_data == 1){								// f[^̎
			if(cp <= (unsigned long)cpm_to_uSv_ofs){		// lJEgl
				cp = (unsigned long)0;
			}else{
				cp -= (unsigned long)cpm_to_uSv_ofs;		// JEgl
			}
			ul = (((unsigned long)cp * (unsigned long)1000) / (unsigned long)cpm_to_uSv_spn);	// 0.01PʂuSv
		}else{												// f[^̎
			if(cp <= ((unsigned long)cpm_to_uSv_ofs * (unsigned long)60)){				// lJEgl
				cp = 0;
			}else{
				cp -= ((unsigned long)cpm_to_uSv_ofs * (unsigned long)60);				// JEgl
			}
			ul = (((unsigned long)cp * (unsigned long)1000) / ((unsigned long)cpm_to_uSv_spn * (unsigned long)60));	// 0.01PʂuSv
		}
		if((unsigned long)999999 < ul){
			ul = (unsigned long)999999;
		}
		if(ul <= 999){										// 9.99 ȉ(00999)
			wtod_05u((char *)disp_moji,(unsigned int)ul);	// ɂ
			disp_moji[6] = disp_moji[5];
			disp_moji[5] = disp_moji[4];
			disp_moji[4] = disp_moji[3];
			disp_moji[3] = '.';
			disp_lcd_G(x, y, &disp_moji[2]);				// display Dot Matrix LCD Up or Down Side
		}else if(ul <= 9999){								// 99.9 ȉ(09999)
			wtod_05u((char *)disp_moji,(unsigned int)ul);	// ɂ
			disp_moji[4] = disp_moji[3];
			disp_moji[3] = '.';
			if(disp_moji[1] == '0'){
				disp_moji[1] = ' ';
			}
			disp_lcd_G(x, y, &disp_moji[1]);				// display Dot Matrix LCD Up or Down Side
		}else{												// (999999)
			wtod_5u((char *)disp_moji,(unsigned int)(ul / (unsigned int)100));	// _ŕɂ
			disp_lcd_G(x, y, &disp_moji[1]);				// display Dot Matrix LCD Up or Down Side
		}
	}

	if(unit_ari == 1){										// Pʕ\(uSv/h) LɎ
		get_pgm_str(&str_uSv[0]);							// vÖ̕("uSv")擾
		disp_lcd_G(x+5,y,disp_moji);						// \
		get_pgm_str(&str_per_h[0]);							// vÖ̕("/h")擾
		disp_lcd_G(x+8,y,disp_moji);						// \
	}
}
//*****************************************
// rZ̎擾iPԂ̃JEgPԂ̃JEgɂj
//  FJEgli@́@j
//  QF1:PԒl@́@0:PԒl
//   disp_moji[] ɓ
//*****************************************
void	get_uSv_at_count(unsigned long cp, unsigned char minute_data)
{
	unsigned long	ul;
	char			mm[21];

	if((cp == 0xffff)&&(minute_data == 1)){					// f[^
		get_pgm_str(&str_5minus[0]);						// vÖ̕("----")擾
		llstrcpy(mm,(char *)(&disp_moji[1]));
		llstrcpy((char *)(disp_moji), mm);
	}else if(cp == 0xffffffff){								// f[^
		get_pgm_str(&str_5minus[0]);						// vÖ̕("----")擾
		llstrcpy(mm,(char *)(&disp_moji[1]));
		llstrcpy((char *)(disp_moji), mm);
	}else{
		if(minute_data == 1){								// f[^̎
			if(cp <= (unsigned long)cpm_to_uSv_ofs){		// lJEgl
				cp = (unsigned long)0;
			}else{
				cp -= (unsigned long)cpm_to_uSv_ofs;		// JEgl
			}
			ul = (((unsigned long)cp * (unsigned long)1000) / (unsigned long)cpm_to_uSv_spn);	// 0.01PʂuSv
		}else{												// f[^̎
			if(cp <= ((unsigned long)cpm_to_uSv_ofs * (unsigned long)60)){				// lJEgl
				cp = 0;
			}else{
				cp -= ((unsigned long)cpm_to_uSv_ofs * (unsigned long)60);				// JEgl
			}
			ul = (((unsigned long)cp * (unsigned long)1000) / ((unsigned long)cpm_to_uSv_spn * (unsigned long)60));	// 0.01PʂuSv
		}
		if((unsigned long)999999 < ul){
			ul = (unsigned long)999999;
		}
		if(ul <= 999){										// 9.99 ȉ(00999)
			wtod_05u((char *)disp_moji,(unsigned int)ul);	// ɂ
			disp_moji[6] = disp_moji[5];
			disp_moji[5] = disp_moji[4];
			disp_moji[4] = disp_moji[3];
			disp_moji[3] = '.';
			llstrcpy(mm,(char *)(&disp_moji[2]));
			llstrcpy((char *)(disp_moji), mm);
		}else if(ul <= 9999){								// 99.9 ȉ(09999)
			wtod_05u((char *)disp_moji,(unsigned int)ul);	// ɂ
			disp_moji[4] = disp_moji[3];
			disp_moji[3] = '.';
			if(disp_moji[1] == '0'){
				disp_moji[1] = ' ';
			}
			llstrcpy(mm,(char *)(&disp_moji[1]));
			llstrcpy((char *)(disp_moji), mm);
		}else{												// (999999)
			wtod_5u((char *)disp_moji,(unsigned int)(ul / (unsigned int)100));	// _ŕɂ
			llstrcpy(mm,(char *)(&disp_moji[1]));
			llstrcpy((char *)(disp_moji), mm);
		}
	}
}

//*****************************************
// Q̃XCb`Q@܂ŉiv[v
//  XCb`rbǵA`^Op^C}[Ɂ@荞݂͎gȂ
//  \tgEFA^C}[gp
//*****************************************
void	wait_sw_off(void)
{
	while(1){
		if((PIND & (SW_LEFT | SW_RIGHT)) == (SW_LEFT | SW_RIGHT)){
			delay_ms(100);												// 100mS Delay
			if((PIND & (SW_LEFT | SW_RIGHT)) == (SW_LEFT | SW_RIGHT)){
				break;													// {ɗꂽƂ
			}
		}
	}
}

//*****************************************
// obNCĝnm^nees
//*****************************************
void	proc_back_light(void)
{
	if(back_light_mode == 2){				// obNCg_[h̎
		back_light(1);						// obNCg_
	}else if(back_light_mode == 1){			// obNCg_ij[h̎
		if(tim_1s_back_light != 0){			// obNCgp^C}[OłȂ
			back_light(1);					// obNCg_
		}else{
			back_light(0);					// obNCg
		}
	}else{									// obNCg[h̎
		back_light(0);						// obNCg
	}
}
//*****************************************
// obNCg̎nmX^[gs
//*****************************************
void	start_back_light(void)
{
	if(back_light_mode == 1){						// obNCg_ij[h̎
		tim_1s_back_light = TIM_BACK_LIGHT_ON;		// obNCgp^C}[Zbg
	}
}
//*****************************************
// ۑf[^iPԖ͂PԂƁj̕\
// cph: 0=cpm Data, 1=cph Data, 2=cpd Data
//*****************************************
void	disp_cph_save_data(unsigned char cph)
{
	unsigned char	j;
	unsigned char	i;
	unsigned char	uc;
	unsigned long	ul;
	unsigned int	ui;
	unsigned char	saidai;
	unsigned char	end = 0;
#ifdef		CONFIG_BACK_LIGHT_ON
	unsigned char	ucc;
#endif		//CONFIG_BACK_LIGHT_ON

	disp_clear_lcd_G();								// Clear Display
	get_pgm_str(&str_save_data[0]);					// PԖf[^̃^Cg擾
	disp_lcd_G(1,0,disp_moji);						// \
	if(cph == 0){									// PԂƃf[^(cpm)̎
		get_pgm_str(&str_cpm[0]);					// ̎擾
		disp_lcd_G(5,0,disp_moji);					// \
	}else if(cph == 1){								// PԂƃf[^(cph)̎
		get_pgm_str(&str_cph[0]);					// ̎擾
		disp_lcd_G(5,0,disp_moji);					// \
	}else{											// Pƃf[^(cpd)̎
		get_pgm_str(&str_cpd[0]);					// ̎擾
		disp_lcd_G(5,0,disp_moji);					// \
	}

	wait_sw_off();									// Q̃XCb`Q@܂ŉiv[v

	eeprom_busy_wait();
	if(cph == 0){									// PԂƃf[^(cpm)̎
		uc = eeprom_read_byte(&eep_cpm_write_pos);	// ̕ۑʒu
		saidai = N_of_EEP_MINUTE_DATA;
	}else if(cph == 1){								// PԖf[^̎
		uc = eeprom_read_byte(&eep_cph_write_pos);	// ̕ۑʒu
		saidai = N_of_EEP_HOUR_DATA;
	}else{											// Pf[^̎
		uc = eeprom_read_byte(&eep_cpd_write_pos);	// ̕ۑʒu
		saidai = N_of_EEP_DAY_DATA;
	}
	if(uc == 0xff){									// ۑ
		get_pgm_str(&str_no_data[0]);				// vÖ̕("No Data !!")擾
		disp_lcd_G( 3,1,disp_moji);					// \
	
		delay_ms(4000);								// 4000mS Delay

	}else{												// ۑL鎞
		i = 1;
		for(;;){
			if(i == 0){
				disp_clear_lcd_G();						// Clear Display
				get_pgm_str(&str_display_end[0]);		// vÖ̕("Display End")擾
				disp_lcd_G( 0,1,disp_moji);				// \
				get_pgm_str(&str_era_y_n[0]);			// vÖ̕("Y:R-SW N:L-SW")擾
				disp_lcd_G( 0,2,disp_moji);				// \
				i++;
			}else{
				for(j= 0; j<3; j++){
					uc--;
					if(saidai <= uc){
						uc = (saidai - 1);
					}

					wtod_02u((char *)(&disp_moji[1]), i);		// ԍ
					if(disp_moji[1]=='0'){
						disp_moji[0]=' ';
						disp_moji[1]='-';
					}else{
						disp_moji[0]='-';
					}
					disp_lcd_G(0, 1+j*2, &disp_moji[0]);								// display Dot Matrix LCD Down Side

					eeprom_busy_wait();
					if(cph == 0){														// PԂƃf[^(cpm)̎
						ul = eeprom_read_dword(eep_minute_time_data + uc);				// PԖf[^̎ǂݏo
					}else if(cph == 1){													// PԖf[^(cph)̎
						ul = eeprom_read_dword(eep_hour_time_data + uc);				// PԖf[^̎ǂݏo
					}else{																// Pf[^(cpd)̎
						ul = eeprom_read_dword(eep_day_time_data + uc);					// Pf[^̎ǂݏo
					}
					convert_display_date_time(ul);										// unsigned long ̒l\pɕϊ
					disp_lcd_G(4,1+j*2,disp_moji);										// \

					eeprom_busy_wait();
					if(cph == 0){														// PԂƃf[^(cpm)̎
						ul = (unsigned long)eeprom_read_word(eep_minute_data + uc);		// PԖf[^̓ǂݏo
						if(ul == 0xffff){
							ul = 0xffffffff;
						}
					}else if(cph == 1){													// PԖf[^(cph)̎
						ul = eeprom_read_dword(eep_hour_data + uc);						// PԖf[^̓ǂݏo
					}else{																// Pf[^(cpd)̎
						ul = eeprom_read_dword(eep_day_data + uc);						// Pf[^̓ǂݏo
					}
					if(ul == 0xffffffff){
						get_pgm_str(&str_5minus[0]);									// "-----"
						disp_lcd_G(2,2+j*2,&disp_moji[0]);								// \
						disp_lcd_G(7,2+j*2,&disp_moji[3]);								// \
						disp_lcd_G(11,2+j*2,&disp_moji[1]);								// \
					}else{
						ui = (unsigned short)(ul/10000);
						wtod_7u((char *)disp_moji, ul);									// PԖ͂PԂƂ̃JEg
						disp_lcd_G(2, 2+j*2, &disp_moji[0]);							// display Dot Matrix LCD Down Side
						if(cph == 0){													// PԂƃf[^(cpm)̎
							disp_uSv_at_count(11, 2+j*2, ul, 1, 0);						// rZ\iPԂ̃JEgɂj
						}else if(cph == 2){
							disp_uSv_at_count(11, 2+j*2, ul/(unsigned long)24, 0, 0);	// rZ\iPԂ̃JEgɂj
						}else{
							disp_uSv_at_count(11, 2+j*2, ul, 0, 0);						// rZ\iPԂ̃JEgɂj
						}

					}

					i++;
					if(saidai < i){
						// c̑O\NA
						j++;
						for(;j<3;j++){
							get_pgm_str(&str_space10[0]);		// vÖ̕("      ")擾
							disp_lcd_G( 0,1+j*2,disp_moji);		// \
							disp_lcd_G(10,1+j*2,disp_moji);		// \
							disp_lcd_G( 0,2+j*2,disp_moji);		// \
							disp_lcd_G(10,2+j*2,disp_moji);		// \
						}
						i = 0;
						break;
					}
				}
			}
			wait_sw_off();									// Q̃XCb`Q@܂ŉiv[v

// XCb`ꂽi܂ŉiv[vj
#ifdef		CONFIG_BACK_LIGHT_ON
			ucc = 10;
#endif		//CONFIG_BACK_LIGHT_ON
			while(1){
				if((PIND & SW_LEFT) == 0){
					delay_ms(50);							// 50mS Delay
					if((PIND & SW_LEFT) == 0){
#ifdef		CONFIG_BACK_LIGHT_ON
						start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
						break;								// {ɉꂽƂ
					}
				}else if( ((PIND & SW_RIGHT) == 0)&&(i == 1)){
					delay_ms(100);							// 100mS Delay
					if((PIND & SW_RIGHT) == 0){
						end = 1;
#ifdef		CONFIG_BACK_LIGHT_ON
						start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
						break;
					}
				}

#ifdef		CONFIG_BACK_LIGHT_ON
				delay_ms(100);
				ucc--;
				if(ucc == 0){
					ucc = 10;
					if(tim_1s_back_light != 0){
						tim_1s_back_light--;
					}
				}
				proc_back_light();									// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON
			}

			if(end == 1){
				break;
			}
			if(i == 1){
				disp_clear_lcd_G();							// Clear Display
				get_pgm_str(&str_save_data[0]);				// PԖf[^̃^Cg擾
				disp_lcd_G(1,0,disp_moji);					// \
				if(cph == 0){								// PԂƃf[^(cpm)̎
					get_pgm_str(&str_cpm[0]);				// ̎擾
					disp_lcd_G(5,0,disp_moji);				// \
				}else if(cph == 1){							// PԂƃf[^(cph)̎
					get_pgm_str(&str_cph[0]);				// ̎擾
					disp_lcd_G(5,0,disp_moji);				// \
				}else{										// Pƃf[^(cpd)̎
					get_pgm_str(&str_cpd[0]);				// ̎擾
					disp_lcd_G(5,0,disp_moji);				// \
				}
			}

		}
	}
}
//*****************************************
// ۑf[^iPԖ͂PԂƁj̕\
//  qsbij̏
// cph: 0=cpm Data, 1=cph Data, 2=cpd Data
//*****************************************
void	disp_cph_save_data_NO_RTC(unsigned char cph)
{
	unsigned char	j;
	unsigned char	i;
	unsigned char	uc;
	unsigned long	ul;
	unsigned int	ui;
	unsigned char	saidai;
	unsigned char	end = 0;
#ifdef		CONFIG_BACK_LIGHT_ON
	unsigned char	ucc;
#endif		//CONFIG_BACK_LIGHT_ON

	disp_clear_lcd_G();								// Clear Display
	get_pgm_str(&str_save_data_NO_RTC[0]);			// PԖf[^̃^Cg擾
	disp_lcd_G(1,0,disp_moji);						// \
	if(cph == 0){									// PԂƃf[^(cpm)̎
		get_pgm_str(&str_cpm[0]);					// ̎擾
		disp_lcd_G(8,0,disp_moji);					// \
	}else if(cph == 1){								// PԂƃf[^(cph)̎
		get_pgm_str(&str_cph[0]);					// ̎擾
		disp_lcd_G(8,0,disp_moji);					// \
	}else{											// Pƃf[^(cpd)̎
		get_pgm_str(&str_cpd[0]);					// ̎擾
		disp_lcd_G(8,0,disp_moji);					// \
	}

	wait_sw_off();									// Q̃XCb`Q@܂ŉiv[v

	eeprom_busy_wait();
	if(cph == 0){									// PԂƃf[^(cpm)̎
		uc = eeprom_read_byte(&eep_cpm_write_pos);	// ̕ۑʒu
		saidai = N_of_EEP_MINUTE_DATA;
	}else if(cph == 1){								// PԖf[^̎
		uc = eeprom_read_byte(&eep_cph_write_pos);	// ̕ۑʒu
		saidai = N_of_EEP_HOUR_DATA;
	}else{											// Pf[^̎
		uc = eeprom_read_byte(&eep_cpd_write_pos);	// ̕ۑʒu
		saidai = N_of_EEP_DAY_DATA;
	}
	if(uc == 0xff){									// ۑ
		get_pgm_str(&str_no_data[0]);				// vÖ̕("No Data !!")擾
		disp_lcd_G( 3,1,disp_moji);					// \
	
		delay_ms(4000);								// 4000mS Delay

	}else{												// ۑL鎞
		i = 1;
		for(;;){
			if(i == 0){
				disp_clear_lcd_G();						// Clear Display
				get_pgm_str(&str_display_end[0]);		// vÖ̕("Display End")擾
				disp_lcd_G( 0,1,disp_moji);				// \
				get_pgm_str(&str_era_y_n[0]);			// vÖ̕("Y:R-SW N:L-SW")擾
				disp_lcd_G( 0,2,disp_moji);				// \
				i++;
			}else{
				for(j= 0; j<7; j++){
					uc--;
					if(saidai <= uc){
						uc = (saidai - 1);
					}

					wtod_02u((char *)(&disp_moji[1]), i);		// ԍ
					if(disp_moji[1]=='0'){
						disp_moji[0]=' ';
						disp_moji[1]='-';
					}else{
						disp_moji[0]='-';
					}
					disp_lcd_G(0, 1+j, &disp_moji[0]);								// display Dot Matrix LCD Down Side

					eeprom_busy_wait();
					if(cph == 0){														// PԂƃf[^(cpm)̎
						ul = (unsigned long)eeprom_read_word(eep_minute_data + uc);		// PԖf[^̓ǂݏo
						if(ul == 0xffff){
							ul = 0xffffffff;
						}
					}else if(cph == 1){													// PԖf[^(cph)̎
						ul = eeprom_read_dword(eep_hour_data + uc);						// PԖf[^̓ǂݏo
					}else{																// Pf[^(cpd)̎
						ul = eeprom_read_dword(eep_day_data + uc);						// Pf[^̓ǂݏo
					}
					if(ul == 0xffffffff){
						get_pgm_str(&str_5minus[0]);									// "-----"
						disp_lcd_G(5,1+j,&disp_moji[0]);								// \
						disp_lcd_G(10,1+j,&disp_moji[3]);								// \
						disp_lcd_G(14,1+j,&disp_moji[1]);								// \
					}else{
						ui = (unsigned short)(ul/10000);
						wtod_7u((char *)disp_moji, ul);									// PԖ͂PԂƂ̃JEg
						disp_lcd_G(5, 1+j, &disp_moji[0]);							// display Dot Matrix LCD Down Side
						if(cph == 0){													// PԂƃf[^(cpm)̎
							disp_uSv_at_count(14, 1+j, ul, 1, 0);						// rZ\iPԂ̃JEgɂj
						}else if(cph == 2){
							disp_uSv_at_count(14, 1+j, ul/(unsigned long)24, 0, 0);	// rZ\iPԂ̃JEgɂj
						}else{
							disp_uSv_at_count(14, 1+j, ul, 0, 0);						// rZ\iPԂ̃JEgɂj
						}

					}

					i++;
					if(saidai < i){
						// c̑O\NA
						j++;
						for(;j<7;j++){
							get_pgm_str(&str_space10[0]);		// vÖ̕("      ")擾
							disp_lcd_G( 0,1+j,disp_moji);		// \
							disp_lcd_G(10,1+j,disp_moji);		// \
						}
						i = 0;
						break;
					}
				}
			}
			wait_sw_off();									// Q̃XCb`Q@܂ŉiv[v

			// XCb`ꂽi܂ŉiv[vj
#ifdef		CONFIG_BACK_LIGHT_ON
			ucc = 10;
#endif		//CONFIG_BACK_LIGHT_ON
			while(1){
				if((PIND & SW_LEFT) == 0){
					delay_ms(50);							// 50mS Delay
					if((PIND & SW_LEFT) == 0){
#ifdef		CONFIG_BACK_LIGHT_ON
						start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
						break;								// {ɉꂽƂ
					}
				}else if( ((PIND & SW_RIGHT) == 0)&&(i == 1)){
					delay_ms(100);							// 100mS Delay
					if((PIND & SW_RIGHT) == 0){
						end = 1;
#ifdef		CONFIG_BACK_LIGHT_ON
						start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
						break;
					}
				}

#ifdef		CONFIG_BACK_LIGHT_ON
				delay_ms(100);
				ucc--;
				if(ucc == 0){
					ucc = 0;
					if(tim_1s_back_light != 0){
						tim_1s_back_light--;
					}
				}
				proc_back_light();									// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON
			}

			if(end == 1){
				break;
			}
			if(i == 1){
				disp_clear_lcd_G();							// Clear Display
				get_pgm_str(&str_save_data_NO_RTC[0]);		// PԖf[^̃^Cg擾
				disp_lcd_G(1,0,disp_moji);					// \
				if(cph == 0){								// PԂƃf[^(cpm)̎
					get_pgm_str(&str_cpm[0]);				// ̎擾
					disp_lcd_G(8,0,disp_moji);				// \
				}else if(cph == 1){							// PԂƃf[^(cph)̎
					get_pgm_str(&str_cph[0]);				// ̎擾
					disp_lcd_G(8,0,disp_moji);				// \
				}else{										// Pƃf[^(cpd)̎
					get_pgm_str(&str_cpd[0]);				// ̎擾
					disp_lcd_G(8,0,disp_moji);				// \
				}
			}

		}
	}
}
//*****************************************
// ۑf[^iPԖ͂PԂƁj̍폜
// cph: 0=cpm Data, 1=cph Data, 2=cpd Data
//*****************************************
void	clear_cph_save_data(unsigned char cph)
{
#ifdef		CONFIG_BACK_LIGHT_ON
	unsigned char	uc;
#endif		//CONFIG_BACK_LIGHT_ON

	disp_clear_lcd_G();								// Clear Display
	if(cph == 0){									// PԂƃf[^(cpm)̎
		get_pgm_str(&str_cpm[0]);					// ̎擾
		disp_lcd_G(0,0,disp_moji);					// \
	}else if(cph == 1){								// PԂƃf[^(cph)̎
		get_pgm_str(&str_cph[0]);					// ̎擾
		disp_lcd_G(0,0,disp_moji);					// \
	}else{											// Pƃf[^(cpd)̎
		get_pgm_str(&str_cpd[0]);					// ̎擾
		disp_lcd_G(0,0,disp_moji);					// \
	}
	get_pgm_str(&str_data_delete[0]);				// vÖ̕("Data Delete ?")擾
	disp_lcd_G( 0,1,disp_moji);						// \

	wait_sw_off();									// Q̃XCb`Q@܂ŉiv[v

	get_pgm_str(&str_era_y_n[0]);					// vÖ̕("Y:R-SW N:L-SW")擾
	disp_lcd_G( 3,5,disp_moji);						// \

// XCb`ꂽi܂ŉiv[vj
#ifdef		CONFIG_BACK_LIGHT_ON
	uc = 10;
#endif		//CONFIG_BACK_LIGHT_ON
	while(1){
		if((PIND & SW_LEFT) == 0){
			delay_ms(50);							// 50mS Delay
			if((PIND & SW_LEFT) == 0){
#ifdef		CONFIG_BACK_LIGHT_ON
				start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
				break;								// {ɉꂽƂ
			}
		}else if( (PIND & SW_RIGHT) == 0 ){
			delay_ms(100);							// 100mS Delay
			if((PIND & SW_RIGHT) == 0){
				if(cph == 0){						// PԂƃf[^(cpm)̎
					delete_minute_data();			// PԖf[^̑S
				}else if(cph == 1){					// PԖf[^̎
					delete_hour_data();				// PԖf[^̑S
				}else{								// Pf[^̎
					delete_day_data();				// Pf[^̑S
				}
				get_pgm_str(&str_space10[0]);		// vÖ̕("      ")擾
				disp_lcd_G( 0,5,disp_moji);			// \
				disp_lcd_G(10,5,disp_moji);			// \
				get_pgm_str(&str_done[0]);			// vÖ̕("Done")擾
				disp_lcd_G( 8,5,disp_moji);			// \
				delay_ms(2000);						// 2000mS Delay

#ifdef		CONFIG_BACK_LIGHT_ON
				start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
				break;
			}
		}
#ifdef		CONFIG_BACK_LIGHT_ON
		delay_ms(100);								// 100mS Delay
		uc--;
		if(uc == 0){
			uc = 10;
			if(tim_1s_back_light != 0){
				tim_1s_back_light--;
			}
		}
		proc_back_light();							// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON
	}
}
//*****************************************
// ۑf[^iA  j̑I
//   OFl\
//  @@ PFOt\
//  @@ QFM
//  @@ RF
//*****************************************
void	select_save_data(unsigned char proc_sel)
{
	unsigned char	sel=0;
	unsigned char	kesu=1;

	disp_clear_lcd_G();								// Clear Display
	if(proc_sel == 3){
		get_pgm_str(&str_save_data_delete[0]);		// vÖ̕("Delete Save Data")擾
	}else if(proc_sel == 2){
		get_pgm_str(&str_save_data_transmit[0]);	// vÖ̕("Transmit Save Data")擾
	}else if(proc_sel == 1){
		get_pgm_str(&str_save_data_graph[0]);		// vÖ̕("Graph Save Data")擾
	}else{
		get_pgm_str(&str_display_save_data[0]);		// vÖ̕("Display Save Data")擾
	}
	disp_lcd_G( 0,0,disp_moji);						// \
	get_pgm_str(&str_save_select1[0]);				// vÖ̕("Sel cpm or cph ?")擾
	disp_lcd_G( 0,1,disp_moji);						// \

	get_pgm_str(&str_cpm[0]);						// "cpm"
	disp_lcd_G( 0,2,disp_moji);						// \
	get_pgm_str(&str_cph[0]);						// "cph"
	disp_lcd_G( 0,3,disp_moji);						// \
	get_pgm_str(&str_cpd[0]);						// "cpd"
	disp_lcd_G( 0,4,disp_moji);						// \

	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ

	Timer2_init();										// Timer2 Initial

	sei();												// 荞݉

	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp
	while(1){
		if(tim_10ms_buz == 0){												// TOOr̕\iuU[p^C}[pj
			tim_10ms_buz = 50;

			kesu ^= 1;														// I̓_
			if(kesu == 0){													// _ł̓_̎
				get_pgm_str(&str_cpm[0]);									// "cpm"
				disp_lcd_G( 0,2,disp_moji);									// \
				get_pgm_str(&str_cph[0]);									// "cph"
				disp_lcd_G( 0,3,disp_moji);									// \
				get_pgm_str(&str_cpd[0]);									// "cpd"
				disp_lcd_G( 0,4,disp_moji);									// \
			}else{															// _ł̖ł̎
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(sel == 0){
					disp_lcd_G(0,2, &disp_moji[0]);							// Xy[X\
				}else if(sel == 1){
					disp_lcd_G(0,3, &disp_moji[0]);							// Xy[X\
				}else{
					disp_lcd_G(0,4, &disp_moji[0]);							// Xy[X\
				}
			}
		}
		get_sw();															//@XCb`Ԃ
		if(sw[2] != 0){														// ꂽXCb`L鎞
#ifdef		CONFIG_BACK_LIGHT_ON
			start_back_light();												// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			if((sw[2] & SW_LEFT) != 0){										// XCb`
				sel++;
				if(2 < sel){
					sel = 0;
				}
			}else if((sw[2] & SW_RIGHT) != 0){								// EXCb`
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(sel == 0){
					disp_lcd_G(0,3, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(0,4, &disp_moji[0]);							// Xy[X\
					get_pgm_str(&str_cpm[0]);								// "cpm"
					disp_lcd_G( 0,2,disp_moji);								// \
				}else if(sel == 1){
					disp_lcd_G(0,2, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(0,4, &disp_moji[0]);							// Xy[X\
					get_pgm_str(&str_cph[0]);								// "cph"
					disp_lcd_G( 0,3,disp_moji);								// \
				}else{
					disp_lcd_G(0,2, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(0,3, &disp_moji[0]);							// Xy[X\
					get_pgm_str(&str_cpd[0]);								// "cpd"
					disp_lcd_G(0,4,disp_moji);								// \
				}
				break;
			}
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();													// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON
	}
	wait_key_off();											// Q̃XCb`Q@܂ŉiv[v

	cli();

	if(proc_sel == 3){
		if(sel == 0){										// cpm
			clear_cph_save_data(0);							// ۑf[^iPAPԖ͂PԂƁj̍폜
		}else if(sel == 1){									// cph
			clear_cph_save_data(1);							// ۑf[^iPAPԖ͂PԂƁj̍폜
		}else{												// cpd
			clear_cph_save_data(2);							// ۑf[^iPAPԖ͂PԂƁj̍폜
		}
	}else if(proc_sel == 2){
		if(sel == 0){										// cpm
			transmit_cph_save_data(0);						// ۑf[^iPԂƁj̑M
		}else if(sel == 1){									// cph
			transmit_cph_save_data(1);						// ۑf[^iPԂƁj̑M
		}else{												// cpd
			transmit_cph_save_data(2);						// ۑf[^iPƁj̑M
		}
	}else if(proc_sel == 1){
#ifdef	NON_RTC												// RTC 
		if(sel == 0){										// cpm
			graph_cph_save_data_NO_RTC(0);					// ۑf[^iPԂƁj̃Ot\
		}else if(sel == 1){									// cph
			graph_cph_save_data_NO_RTC(1);					// ۑf[^iPԂƁj̃Ot\
		}else{												// cpd
			graph_cph_save_data_NO_RTC(2);					// ۑf[^iPƁj̃Ot\
		}
#else	//NON_RTC
		if(sel == 0){										// cpm
			graph_cph_save_data(0);							// ۑf[^iPԂƁj̃Ot\
		}else if(sel == 1){									// cph
			graph_cph_save_data(1);							// ۑf[^iPԂƁj̃Ot\
		}else{												// cpd
			graph_cph_save_data(2);							// ۑf[^iPƁj̃Ot\
		}
#endif	//NON_RTC
	}else{
#ifdef	NON_RTC												// RTC
		if(sel == 0){										// cpm
			disp_cph_save_data_NO_RTC(0);					// ۑf[^iPAPԖ͂PԂƁj̕\
		}else if(sel == 1){									// cph
			disp_cph_save_data_NO_RTC(1);					// ۑf[^iPAPԖ͂PԂƁj̕\
		}else{												// cpd
			disp_cph_save_data_NO_RTC(2);					// ۑf[^iPAPԖ͂PԂƁj̕\
		}
#else	//NON_RTC
		if(sel == 0){										// cpm
			disp_cph_save_data(0);							// ۑf[^iPAPԖ͂PԂƁj̕\
		}else if(sel == 1){									// cph
			disp_cph_save_data(1);							// ۑf[^iPAPԖ͂PԂƁj̕\
		}else{												// cpd
			disp_cph_save_data(2);							// ۑf[^iPAPԖ͂PԂƁj̕\
		}
#endif	//NON_RTC
	}
}
//*****************************************
// ۑf[^̑I
//*****************************************
void	select_proc_save_data(void)
{
	unsigned char	sel=0;									//0:"Display Value", 1:"Display Graph", 2:"Tranmit", 3:"Delete"
	unsigned char	kesu=1;

	disp_clear_lcd_G();									// Clear Display
	get_pgm_str(&str_save_sel_proc[0]);					// vÖ̕("Select Process")擾
	disp_lcd_G( 0,0,disp_moji);							// \
	get_pgm_str(&str_for_save_date[0]);					// vÖ̕(" for Save Data")擾
	disp_lcd_G( 0,1,disp_moji);							// \

	get_pgm_str(&str_disp_vul[0]);						// "Display Value"
	disp_lcd_G( 0,2,disp_moji);							// \
	get_pgm_str(&str_disp_grh[0]);						// "Display Graph"
	disp_lcd_G( 0,3,disp_moji);							// \
	get_pgm_str(&str_transmit[0]);						// "Transmit"
	disp_lcd_G( 0,4,disp_moji);							// \
	get_pgm_str(&str_delete[0]);						// "Delete"
	disp_lcd_G( 0,5,disp_moji);							// \

	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ

	Timer2_init();										// Timer2 Initial
	read_hv_target_volt(0);								// gu@o͒l̓ǂݏo

	sei();												// 荞݉

	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp
	while(1){
		if(tim_10ms_buz == 0){												// TOOr̕\iuU[p^C}[pj
			tim_10ms_buz = 50;

			kesu ^= 1;														// I̓_
			if(kesu == 0){													// _ł̓_̎
				get_pgm_str(&str_disp_vul[0]);								// "Display Value"
				disp_lcd_G( 0,2,disp_moji);									// \
				get_pgm_str(&str_disp_grh[0]);								// "Display Graph"
				disp_lcd_G( 0,3,disp_moji);									// \
				get_pgm_str(&str_transmit[0]);								// "Transmit"
				disp_lcd_G( 0,4,disp_moji);									// \
				get_pgm_str(&str_delete[0]);								// "Delete"
				disp_lcd_G( 0,5,disp_moji);									// \
			}else{															// _ł̖ł̎
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(sel == 0){
					disp_lcd_G(0,2, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(10,2, &disp_moji[7]);						// Xy[X\
				}else if(sel == 1){
					disp_lcd_G(0,3, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(10,3, &disp_moji[7]);						// Xy[X\
				}else if(sel == 2){
					disp_lcd_G(0,4, &disp_moji[0]);							// Xy[X\
				}else{
					disp_lcd_G(0,5, &disp_moji[0]);							// Xy[X\
				}
			}
		}
		get_sw();															//@XCb`Ԃ
		if(sw[2] != 0){														// ꂽXCb`L鎞
#ifdef		CONFIG_BACK_LIGHT_ON
			start_back_light();												// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			if((sw[2] & SW_LEFT) != 0){										// XCb`
				sel++;
				if(3 < sel){
					sel = 0;
				}
			}else if((sw[2] & SW_RIGHT) != 0){								// EXCb`
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(sel == 0){
					disp_lcd_G(0,3, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(10,3, &disp_moji[7]);						// Xy[X\
					disp_lcd_G(0,4, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(0,5, &disp_moji[0]);							// Xy[X\
					get_pgm_str(&str_disp_vul[0]);							// "Display Value"
					disp_lcd_G( 0,2,disp_moji);								// \
				}else if(sel == 1){
					disp_lcd_G(0,2, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(10,2, &disp_moji[7]);						// Xy[X\
					disp_lcd_G(0,4, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(0,5, &disp_moji[0]);							// Xy[X\
					get_pgm_str(&str_disp_grh[0]);							// "Display Graph"
					disp_lcd_G( 0,3,disp_moji);								// \
				}else if(sel == 2){
					disp_lcd_G(0,2, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(10,2, &disp_moji[7]);						// Xy[X\
					disp_lcd_G(0,3, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(10,3, &disp_moji[7]);						// Xy[X\
					disp_lcd_G(0,5, &disp_moji[0]);							// Xy[X\
					get_pgm_str(&str_transmit[0]);							// "Transmit"
					disp_lcd_G(0,4,disp_moji);								// \
				}else{
					disp_lcd_G(0,2, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(10,2, &disp_moji[7]);						// Xy[X\
					disp_lcd_G(0,3, &disp_moji[0]);							// Xy[X\
					disp_lcd_G(10,3, &disp_moji[7]);						// Xy[X\
					disp_lcd_G(0,4, &disp_moji[0]);							// Xy[X\
					get_pgm_str(&str_delete[0]);							// "Delete"
					disp_lcd_G(0,5,disp_moji);								// \
				}
				break;
			}
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();													// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}
	wait_key_off();															// Q̃XCb`Q@܂ŉiv[v

	cli();

	select_save_data(sel);
}
//*****************************************
// ۑf[^̕\
//*****************************************
void	proc_disp_save_data(void)
{
	if((PIND & (SW_LEFT | SW_RIGHT)) == SW_RIGHT){		// PIND0(Left SW) ݂̂nm
		delay_ms(100);									// 100mS Delay
		if((PIND & (SW_LEFT | SW_RIGHT)) == SW_RIGHT){	// PIND0(Left SW) ݂̂nm
			for(;;){
				select_proc_save_data();				// ۑf[^̑I
			}
		}
	}
}
//*****************************************
// Q̃XCb`Q@܂ŉiv[v
//  XCb`͂Ɋ荞݃^C}[gB
//*****************************************
void	wait_key_off(void)
{
	while(1){											// ̂rv܂ő҂
		get_sw();										//@XCb`Ԃ
		if( (sw[1] & (SW_LEFT | SW_RIGHT)) == 0 ){		// ꂽ
			break;
		}
	}
}
//*****************************************
// obNCg@`tsn^nee
//*****************************************
void	back_light_auto_off(void)
{
	if(back_light_mode == 1){						// 	`tsn̎
		get_pgm_str(&str_back_light_off[0]);		// vÖ̕("Back Light OFF ")擾
		disp_lcd_G( 0,0,disp_moji);					// \
	}else{
		get_pgm_str(&str_back_light_auto[0]);		// vÖ̕("Back Light AUTO")擾
		disp_lcd_G( 0,0,disp_moji);					// \
	}
	wait_sw_off();									// Q̃XCb`Q@܂ŉiv[v

	tim_10ms_sw = 0;								// ROro߂Ƃ
	get_sw();										//@XCb`Ԃ
	tim_10ms_sw = 0;								// ROro߂Ƃ
	get_sw();										//@XCb`Ԃ
	tim_10ms_sw = 0;								// ROro߂Ƃ
	get_sw();										//@XCb`Ԃ

	Timer2_init();									// Timer2 Initial

	sei();											// 荞݉

	wait_key_off();									// Q̃XCb`Q@܂ŉiv[v

	if(back_light_mode == 1){						// 	`tsn̎
		get_pgm_str(&str_back_light_off[0]);		// vÖ̕("Back Light OFF ")擾
		disp_lcd_G( 0,0,disp_moji);					// \
		get_pgm_str(&str_question[0]);				// vÖ̕("?")擾
		disp_lcd_G(14,0,disp_moji);					// \
	}else{
		get_pgm_str(&str_back_light_auto[0]);		// vÖ̕("Back Light AUTO")擾
		disp_lcd_G( 0,0,disp_moji);					// \
		get_pgm_str(&str_question[0]);				// vÖ̕("?")擾
		disp_lcd_G(15,0,disp_moji);					// \
	}
	get_pgm_str(&str_yl_nr[0]);						// vÖ̕("Y:L-SW N:R-SW")擾
	disp_lcd_G( 0,1,disp_moji);						// \

	while(1){
		get_sw();									//@XCb`Ԃ
		if(sw[2] != 0){								// ꂽXCb`L鎞
			if((sw[2] & SW_LEFT) != 0){				// XCb`
				cli();
				back_light_mode ^= 1;				// obNCg[hύX
				save_back_light_mode();				// obNCg[h̕ۑ
				sei();								// 荞݉
#ifdef		CONFIG_BACK_LIGHT_ON
				start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			}
			break;
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();							// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}

	wait_key_off();									// Q̃XCb`Q@܂ŉiv[v

	cli();
}

//*****************************************
// uU[nm^nee
//*****************************************
void	buz_ena_dis(void)
{
#ifdef		CONFIG_BACK_LIGHT_ON
	unsigned char	uc;
#endif		//CONFIG_BACK_LIGHT_ON

	if(buz_on == 1){
		get_pgm_str(&str_buz_disable[0]);			// vÖ̕("Buzzer Disable")擾
		disp_lcd_G( 0,0,disp_moji);					// \
		get_pgm_str(&str_question[0]);				// vÖ̕("?")擾
		disp_lcd_G(15,0,disp_moji);					// \
	}else{
		get_pgm_str(&str_buz_enable[0]);			// vÖ̕("Buzzer Enable")擾
		disp_lcd_G( 0,0,disp_moji);					// \
		get_pgm_str(&str_question[0]);				// vÖ̕("?")擾
		disp_lcd_G(14,0,disp_moji);					// \
	}
	get_pgm_str(&str_yl_nr[0]);						// vÖ̕("Y:L-SW N:R-SW")擾
	disp_lcd_G( 0,1,disp_moji);						// \

	wait_sw_off();									// Q̃XCb`Q@܂ŉiv[v

#ifdef		CONFIG_BACK_LIGHT_ON
	uc = 10;
#endif		//CONFIG_BACK_LIGHT_ON
	while(1){
		if((PIND & SW_LEFT) == 0){
			delay_ms(100);							// 100mS Delay
			if((PIND & SW_LEFT) == 0){
				buz_on ^= 1;						// uU[nm^nee@ύX
				save_buz_on_off();					// uU[nm^nee̕ۑ
#ifdef		CONFIG_BACK_LIGHT_ON
				start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
				break;
			}
		}else if((PIND & SW_RIGHT) == 0){
			delay_ms(100);							// 100mS Delay
			if((PIND & SW_RIGHT) == 0){
#ifdef		CONFIG_BACK_LIGHT_ON
				start_back_light();					// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
				break;
			}
		}
#ifdef		CONFIG_BACK_LIGHT_ON
		delay_ms(100);
		uc--;
		if(uc == 0){
			if(tim_1s_back_light != 0){
				tim_1s_back_light--;
			}
		}
		proc_back_light();							// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}

	wait_sw_off();									// Q̃XCb`Q@܂ŉiv[v
}

//*****************************************
// uU[̂nm^neeݒ
//*****************************************
void	proc_buz_enable(void)
{
	if((PIND & (SW_LEFT | SW_RIGHT)) == SW_LEFT){		// PIND7(Right SW) ݂̂nm
		delay_ms(100);									// 100mS Delay
		if((PIND & (SW_LEFT | SW_RIGHT)) == SW_LEFT){	// PIND7(Right SW) ݂̂nm
			back_light_auto_off();						// obNCg@`tsn^nee
			disp_clear_lcd_G();							// Clear Display
			buz_ena_dis();								// uU[nm^nee
			disp_clear_lcd_G();							// Clear Display
		}
	}
}
//*****************************************
// guj^l(Volt)̎擾
//  Qɓ
//*****************************************
void	get_hv_moni(void)
{
	unsigned int	ui;

	ui = ad7_get_data();									// A/D 7 Get A/D data
	hv_moni = (unsigned int)(((unsigned long)ui * (unsigned long)hv_hosei_spn)/(unsigned long)1000 - HV_HOSEI_OFS_DEFAULT + hv_hosei_ofs);
}
//*****************************************
// guj^l̕\
//*****************************************
void	disp_hv_moni(unsigned char x, unsigned char y)
{
	get_hv_moni();											// guj^l(Volt)̎擾(hv_moni ɓ)
	wtod_5u((char *)disp_moji,hv_moni);						// High Volt Data
	disp_lcd_G(x, y, &disp_moji[2]);						// display Dot Matrix LCD
	get_pgm_str(&str_volt[0]);								// vÖ̕("V")擾
	disp_lcd_G(x+3,y,disp_moji);							// \
}
//*****************************************
// gupo͒l̕\
//*****************************************
void	disp_hv_out(unsigned char x, unsigned char y)
{
	wtod_5u((char *)disp_moji,hv_out);						// High Volt Data
	disp_lcd_G(x, y, &disp_moji[2]);							// display Dot Matrix LCD Up or Down Side
}
//*****************************************
// obej^l(Volt)̎擾
//  Qɓ
//*****************************************
void	get_bat_moni(void)
{
	unsigned int	ui;

	ui = ad6_get_data();									// A/D 6 Get A/D data
	bat_moni = (unsigned int)(((unsigned long)ui * (unsigned long)610) / (unsigned long)1024);
}
//*****************************************
// obej^l̕\
//*****************************************
void	disp_bat_moni(unsigned char x, unsigned char y)
{
	get_bat_moni();											// obej^l(Volt)̎擾(bat_moni ɓ)
	wtod_5u((char *)disp_moji,bat_moni);					// battry Volt Data
	disp_moji[1] = disp_moji[2];
	disp_moji[2] = '.';
	disp_lcd_G(x, y, &disp_moji[1]);						// display Dot Matrix LCD Up or Down Side
}
//*****************************************
// guj^Xp␳l
//*****************************************
void	proc_set_hv_hosei_spn_valu(void)
{
	unsigned char	keta=0;								//0:1000̌, 1:100̌, 2:10̌, 3:1̌
	unsigned char	kesu=1;
	unsigned char	i;
	unsigned char	lo_hi=0;

	ad67_init();										// A/D 6&7 Initial

	disp_clear_lcd_G();									// Clear Display
	get_pgm_str(&str_mon_spn[0]);						// vÖ̕("MON_SPN")擾
	disp_lcd_G( 0,0,disp_moji);							// \

	wtod_05u((char *)disp_moji,hv_hosei_spn);			// Xp␳ Data
	disp_lcd_G( 0,1, &disp_moji[1]);						// \

	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ

	Timer2_init();										// Timer2 Initial

	sei();												// 荞݉

	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	Timer1_init(1);										// Timer1 Initial
	HV_on();											// High Volt ON

	tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp
	while(1){
		if(lo_hi == 1){
			hv_out = 750;
		}else{
			hv_out = 550;
		}
		set_Timer1_ontime();												// Set Timer1 ON Time

		if(tim_10ms_buz == 0){												// TOOr̕\iuU[p^C}[pj
			tim_10ms_buz = 50;
			disp_hv_moni(12,  0);											// guj^l̕\

			kesu ^= 1;														// ␳l̓_
			if(kesu == 0){													// _ł̓_̎
				wtod_05u((char *)disp_moji, hv_hosei_spn);					// Xp␳ Data
				disp_lcd_G( 0,1, &disp_moji[1]);								// \
				get_pgm_str(&str_save_next[0]);								// vÖ̕("Save&Next")擾
				disp_lcd_G( 5,1,disp_moji);									// \
				if(lo_hi == 0){
					get_pgm_str(&str_lo[0]);								// vÖ̕("lo")擾
				}else{
					get_pgm_str(&str_hi[0]);								// vÖ̕("Hi")擾
				}
				disp_lcd_G( 9,0,disp_moji);									// \
			}else{															// _ł̖ł̎
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(keta <= 3){
					disp_lcd_G(keta,1, &disp_moji[9]);						// \ ̏ꏊ
				}else if(keta == 4){
					disp_lcd_G (5,1, disp_moji);							// \@Save & Next ̏ꏊ
				}else{
					disp_lcd_G(9,0, &disp_moji[8]);							// \ Hi or Lo ̏ꏊ
				}
			}
		}
		get_sw();															//@XCb`Ԃ
		if(sw[2] != 0){														// ꂽXCb`L鎞
#ifdef		CONFIG_BACK_LIGHT_ON
			start_back_light();												// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			if((sw[2] & SW_LEFT) != 0){										// XCb`
				keta++;
				if(5 < keta){
					keta = 0;
				}
			}else if((sw[2] & SW_RIGHT) != 0){								// EXCb`
				if(keta == 0){												// POOǑ
					if(hv_hosei_spn < 1000){								// POOǑO̎
						hv_hosei_spn += 1000;
					}else{
						hv_hosei_spn %= 1000;
					}
				}else if(keta == 1){										// POǑ
					if( ((hv_hosei_spn % 1000)/100) != 9 ){					// POǑXȊO̎
						hv_hosei_spn += 100;
					}else{
						hv_hosei_spn = ((hv_hosei_spn/1000)*1000)+(hv_hosei_spn % 100);
					}
				}else if(keta == 2){										// PǑ
					if( ((hv_hosei_spn % 100)/10) != 9 ){					// PǑXȊO̎
						hv_hosei_spn += 10;
					}else{
						hv_hosei_spn = ((hv_hosei_spn/100)*100)+(hv_hosei_spn % 10);
					}
				}else if(keta == 3){										// P̌
					if( (hv_hosei_spn % 10) != 9 ){							// P̌XȊO̎
						hv_hosei_spn += 1;
					}else{
						hv_hosei_spn = ((hv_hosei_spn/10)*10);
					}
				}else if(keta == 4){										// Ȉꏊ
					cli();													// 荞ݕs

					for(i=0;i<3;i++){
						eeprom_busy_wait();
						eeprom_write_word(&eep_hv_hosei_spn[i],hv_hosei_spn);	// gu@Xp␳l̕ۑ
					}

					eeprom_busy_wait();
					sei();													// 荞݉
					break;
				}else{														// Hi or Lo ̏ꏊ
					lo_hi ^= 1;
				}
				wtod_05u((char *)disp_moji, hv_hosei_spn);					// Xp␳ Data
				disp_lcd_G( 0,1, &disp_moji[1]);							// \
				kesu = 1;
			}
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();													// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}

	HV_off();											// High Volt OFF
	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	cli();
}

//*****************************************
// guj^ItZbg␳l
// \߁@ItZbgl͕ϐɓǂݍ܂ĂƂ
//*****************************************
void	proc_set_hv_hosei_ofs_valu(void)
{
	unsigned char	keta=0;								//0:100̌, 1:10̌, 2:1̌, 3:Save & Exit, 4:[Hi] or [Lo]
	unsigned char	kesu=1;
	unsigned char	i;
	unsigned char	lo_hi=0;							// 0:Lo, 1:Hi

	disp_clear_lcd_G();									// Clear Display
	get_pgm_str(&str_mon_ofs[0]);						// vÖ̕("MON_OFS")擾
	disp_lcd_G( 0,0,disp_moji);							// \

	wtod_05u((char *)disp_moji,hv_hosei_ofs);			// ItZbg␳ Data
	disp_lcd_G( 0,1, &disp_moji[2]);					// \

	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ

	Timer2_init();										// Timer2 Initial

	sei();												// 荞݉

	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	Timer1_init(1);										// Timer1 Initial
	HV_on();											// High Volt ON

	tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp

	while(1){
		if(lo_hi == 1){
			hv_out = 750;
		}else{
			hv_out = 550;
		}
		set_Timer1_ontime();												// Set Timer1 ON Time

		if(tim_10ms_buz == 0){												// TOOr̕\iuU[p^C}[pj
			tim_10ms_buz = 50;
			disp_hv_moni(12,  0);											// guj^l̕\

			kesu ^= 1;														// ␳l̓_
			if(kesu == 0){													// _ł̓_̎
				wtod_05u((char *)disp_moji, hv_hosei_ofs);					// Xp␳ Data
				disp_lcd_G( 0,1, &disp_moji[2]);								// \
				get_pgm_str(&str_save_exit[0]);								// vÖ̕("Save&Exit")擾
				disp_lcd_G( 6,1,disp_moji);									// \
				if(lo_hi == 0){
					get_pgm_str(&str_lo[0]);								// vÖ̕("lo")擾
				}else{
					get_pgm_str(&str_hi[0]);								// vÖ̕("Hi")擾
				}
				disp_lcd_G( 9,0,disp_moji);									// \
			}else{															// _ł̖ł̎
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(keta <= 2){
					disp_lcd_G(keta,1, &disp_moji[9]);						// \(P̕j
				}else if(keta == 3){
					disp_lcd_G (5,1, disp_moji);							// \(Save & Exit j
				}else if(keta == 4){
					disp_lcd_G (9,0, &disp_moji[8]);						// \([Hi] or [Lo] j
				}
			}
		}
		get_sw();															//@XCb`Ԃ
		if(sw[2] != 0){														// ꂽXCb`L鎞
#ifdef		CONFIG_BACK_LIGHT_ON
			start_back_light();												// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			if((sw[2] & SW_LEFT) != 0){										// XCb`
				keta++;
				if(4 < keta){
					keta = 0;
				}
			}else if((sw[2] & SW_RIGHT) != 0){								// EXCb`
				if(keta == 0){												// POǑ
					if( (hv_hosei_ofs / 100) != 9 ){						// POǑXȊO̎
						hv_hosei_ofs += 100;
					}else{
						hv_hosei_ofs = (hv_hosei_ofs % 100);
					}
				}else if(keta == 1){										// PǑ
					if( ((hv_hosei_ofs % 100)/10) != 9 ){					// PǑXȊO̎
						hv_hosei_ofs += 10;
					}else{
						hv_hosei_ofs = ((hv_hosei_ofs/100)*100)+(hv_hosei_ofs % 10);
					}
				}else if(keta == 2){										// P̌
					if( (hv_hosei_ofs % 10) != 9 ){							// P̌XȊO̎
						hv_hosei_ofs += 1;
					}else{
						hv_hosei_ofs = ((hv_hosei_ofs/10)*10);
					}
				}else if(keta == 3){										// Ȉꏊ
					cli();													// 荞ݕs

					for(i=0;i<3;i++){
						eeprom_busy_wait();
						eeprom_write_word(&eep_hv_hosei_ofs[i],hv_hosei_ofs);	// gu@ItZbg␳l̕ۑ
					}

					eeprom_busy_wait();
					sei();													// 荞݉
					break;
				}else{														// [Hi] or [Lo] ̏ꏊ
					lo_hi ^= 1;
				}
				wtod_05u((char *)disp_moji, hv_hosei_ofs);					// Xp␳ Data
				disp_lcd_G( 0,1, &disp_moji[2]);							// \
				kesu = 1;
			}
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();													// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}

	HV_off();																// High Volt OFF
	wait_key_off();															// Q̃XCb`Q@܂ŉiv[v

	cli();
}

//*****************************************
// guo͒l(Volt)
//*****************************************
void	proc_set_hv_target_volt(void)
{
	unsigned char	keta=0;								//0:100̌, 1:10̌, 2:1̌
	unsigned char	kesu=1;
	unsigned char	t;

	disp_clear_lcd_G();										// Clear Display
	get_pgm_str(&str_hv_volt[0]);						// vÖ̕("HV-VOLT")擾
	disp_lcd_G( 0,0,disp_moji);							// \
	get_pgm_str(&str_adj[0]);							// vÖ̕("Adj")擾
	disp_lcd_G( 8,0,disp_moji);							// \

	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ

	Timer2_init();										// Timer2 Initial

	sei();												// 荞݉

	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	Timer1_init(1);										// Timer1 Initial

	tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp
	while(1){
		if(tim_10ms_buz == 0){												// TOOr̕\iuU[p^C}[pj
			tim_10ms_buz = 50;

			kesu ^= 1;														// ␳l̓_
			if(kesu == 0){													// _ł̓_̎
				wtod_05u((char *)disp_moji, hv_target_volt);				// ␳ Data
				disp_lcd_G( 1,1, &disp_moji[2]);								// \
				get_pgm_str(&str_save_exit[0]);								// vÖ̕("Save&Exit")擾
				disp_lcd_G( 5,1,disp_moji);									// \
			}else{															// _ł̖ł̎
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(keta != 3){
					disp_lcd_G(keta+1,1, &disp_moji[9]);					// Xy[X\
				}else{
					disp_lcd_G (5,1, disp_moji);							// \
				}
			}
		}

		get_sw();															//@XCb`Ԃ
		if(sw[2] != 0){														// ꂽXCb`L鎞
#ifdef		CONFIG_BACK_LIGHT_ON
			start_back_light();												// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			if((sw[2] & SW_LEFT) != 0){										// XCb`
				keta++;
				if(3 < keta){
					keta = 0;
				}
			}else if((sw[2] & SW_RIGHT) != 0){								// EXCb`
				if(keta == 0){												// POǑ
					if( (hv_target_volt/100) <= 5 ){						// POǑTȉ̎
						hv_target_volt += 100;
					}else{
						hv_target_volt = (hv_target_volt % 100);
					}
				}else if(keta == 1){										// PǑ
					if( ((hv_target_volt % 100)/10) != 9 ){					// PǑXȊO̎
						hv_target_volt += 10;
					}else{
						hv_target_volt = ((hv_target_volt/100)*100)+(hv_target_volt % 10);
					}
				}else if(keta == 2){										// P̌
					if( (hv_target_volt % 10) != 9 ){						// P̌XȊO̎
						hv_target_volt += 1;
					}else{
						hv_target_volt = ((hv_target_volt/10)*10);
					}
				}else{														// Ȉꏊ
					cli();													// 荞ݕs

					for(t = 0; t < 3; t++){
						eeprom_busy_wait();
						eeprom_write_word(&eep_hv_target_volt[t],hv_target_volt);	// gu@o͒l(Volt)̕ۑ
					}

					eeprom_busy_wait();
					sei();													// 荞݉
					break;
				}
				wtod_05u((char *)disp_moji, hv_target_volt);				// o͓d Data
				disp_lcd_G( 1,1, &disp_moji[2]);							// \
				kesu = 1;
			}
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();													// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}

	wait_key_off();															// Q̃XCb`Q@܂ŉiv[v

	cli();
}



//*****************************************
// rZl̏
// @荞ݕsŌĂԂ
//*****************************************
void	init_cpm_to_uSv(void)
{
	unsigned char	i;
	unsigned int	i_dim[3];

	// ZlXp
	for(i=0;i<3;i++){
		eeprom_busy_wait();
		i_dim[i] = eeprom_read_word(&eep_cpm_to_uSv_spn[i]);			// rZl
	}

	cpm_to_uSv_spn = tasuuketu_ui(i_dim[0], i_dim[1], i_dim[2], CPM_uSv_h_SPN_DEFAULT);	// 

	if(9999 < cpm_to_uSv_spn){
		cpm_to_uSv_spn = CPM_uSv_h_SPN_DEFAULT;							// 400.0
	}else if(cpm_to_uSv_spn == 0){
		cpm_to_uSv_spn = 1;												// 0.1
	}

	for(i=0;i<3;i++){
		if(cpm_to_uSv_spn != i_dim[i]){
			eeprom_busy_wait();
			eeprom_write_word(&eep_cpm_to_uSv_spn[i],cpm_to_uSv_spn);	// rZl̕ۑ
		}
		eeprom_busy_wait();
	}


	// ZlItZbgilj
	for(i=0;i<3;i++){
		eeprom_busy_wait();
		i_dim[i] = eeprom_read_word(&eep_cpm_to_uSv_ofs[i]);			// rZl
	}

	cpm_to_uSv_ofs = tasuuketu_ui(i_dim[0], i_dim[1], i_dim[2], CPM_uSv_h_OFS_DEFAULT);		// 

	if(100 < cpm_to_uSv_ofs){
		cpm_to_uSv_ofs = CPM_uSv_h_OFS_DEFAULT;							// 0
	}

	for(i=0;i<3;i++){
		if(cpm_to_uSv_ofs != i_dim[i]){
			eeprom_busy_wait();
			eeprom_write_word(&eep_cpm_to_uSv_ofs[i],cpm_to_uSv_ofs);	// rZl̕ۑ
		}
		eeprom_busy_wait();
	}

}
//*****************************************
// rZlXp 999.9
//*****************************************
void	proc_set_cpm_uSv_span(void)
{
	unsigned char	keta=0;								//0:1000̌, 1:100̌, 2:10̌, 3:1̌
	unsigned char	kesu=1;
	unsigned char	i;

	disp_clear_lcd_G();									// Clear Display
	get_pgm_str(&str_cpm_to_uSv[0]);					// vÖ̕("cpm->uSv")擾
	disp_lcd_G( 0,0,disp_moji);							// \
	get_pgm_str(&str_per_h[0]);							// vÖ̕("/h")擾
	disp_lcd_G( 8,0,disp_moji);							// \
	get_pgm_str(&str_span[0]);							// vÖ̕("Span")擾
	disp_lcd_G(11,0,disp_moji);							// \

	wtod_05u((char *)disp_moji,cpm_to_uSv_spn);			// Z Data
	disp_moji[6] = disp_moji[5];
	disp_moji[5] = disp_moji[4];
	disp_moji[4] = '.';
	disp_lcd_G( 0,1, &disp_moji[1]);						// \

	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ

	Timer2_init();										// Timer2 Initial

	sei();												// 荞݉

	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp
	while(1){
		if(tim_10ms_buz == 0){												// TOOr̕\iuU[p^C}[pj
			tim_10ms_buz = 50;

			kesu ^= 1;														// ␳l̓_
			if(kesu == 0){													// _ł̓_̎
				wtod_05u((char *)disp_moji,cpm_to_uSv_spn);					// Z Data
				disp_moji[6] = disp_moji[5];
				disp_moji[5] = disp_moji[4];
				disp_moji[4] = '.';
				disp_lcd_G( 0,1, &disp_moji[1]);								// \
				get_pgm_str(&str_save_next[0]);								// vÖ̕("Save&Next")擾
				disp_lcd_G( 6,1,disp_moji);									// \
			}else{															// _ł̖ł̎
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(keta <= 2){
					disp_lcd_G(keta,1, &disp_moji[9]);						// \
				}else if(keta != 4){
					disp_lcd_G(keta+1,1, &disp_moji[9]);					// \
				}else{
					disp_lcd_G (6,1, disp_moji);							// \
				}
			}
		}
		get_sw();															//@XCb`Ԃ
		if(sw[2] != 0){														// ꂽXCb`L鎞
#ifdef		CONFIG_BACK_LIGHT_ON
			start_back_light();												// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			if((sw[2] & SW_LEFT) != 0){										// XCb`
				keta++;
				if(4 < keta){
					keta = 0;
				}
			}else if((sw[2] & SW_RIGHT) != 0){								// EXCb`
				if(keta == 0){												// POOǑ
					if( ((cpm_to_uSv_spn % 10000)/1000) != 9 ){				// POOǑXȊO̎
						cpm_to_uSv_spn += 1000;
					}else{
						cpm_to_uSv_spn %= 1000;
					}
				}else if(keta == 1){										// POǑ
					if( ((cpm_to_uSv_spn % 1000)/100) != 9 ){				// POǑXȊO̎
						cpm_to_uSv_spn += 100;
					}else{
						cpm_to_uSv_spn = ((cpm_to_uSv_spn/1000)*1000)+(cpm_to_uSv_spn % 100);
					}
				}else if(keta == 2){										// PǑ
					if( ((cpm_to_uSv_spn % 100)/10) != 9 ){					// PǑXȊO̎
						cpm_to_uSv_spn += 10;
					}else{
						cpm_to_uSv_spn = ((cpm_to_uSv_spn/100)*100)+(cpm_to_uSv_spn % 10);
					}
				}else if(keta == 3){										// P̌
					if( (cpm_to_uSv_spn % 10) != 9 ){						// P̌XȊO̎
						cpm_to_uSv_spn += 1;
					}else{
						cpm_to_uSv_spn = ((cpm_to_uSv_spn/10)*10);
					}
				}else{														// Ȉꏊ
					if(cpm_to_uSv_spn == 0){
						cpm_to_uSv_spn = 1;
					}
					cli();													// 荞ݕs

					for(i=0;i<3;i++){
						eeprom_busy_wait();
						eeprom_write_word(&eep_cpm_to_uSv_spn[i],cpm_to_uSv_spn);		// rZl̕ۑ
					}

					eeprom_busy_wait();
					sei();													// 荞݉
					break;
				}
				wtod_05u((char *)disp_moji,cpm_to_uSv_spn);					// Z Data
				disp_moji[6] = disp_moji[5];
				disp_moji[5] = disp_moji[4];
				disp_moji[4] = '.';
				disp_lcd_G( 0,1, &disp_moji[1]);							// \
				kesu = 1;
			}
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();													// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}

	wait_key_off();															// Q̃XCb`Q@܂ŉiv[v

	cli();
}
//*****************************************
// rZlItZbg 100
//*****************************************
void	proc_set_cpm_uSv_ofset(void)
{
	unsigned char	keta=0;								//0:1000̌, 1:100̌, 2:10̌, 3:1̌
	unsigned char	kesu=1;
	unsigned char	i;

	disp_clear_lcd_G();									// Clear Display
	get_pgm_str(&str_cpm_to_uSv[0]);					// vÖ̕("cpm->uSv")擾
	disp_lcd_G( 0,0,disp_moji);							// \
	get_pgm_str(&str_per_h[0]);							// vÖ̕("/h")擾
	disp_lcd_G( 8,0,disp_moji);							// \
	get_pgm_str(&str_offset[0]);						// vÖ̕("Offset")擾
	disp_lcd_G(11,0,disp_moji);							// \

	wtod_05u((char *)disp_moji,cpm_to_uSv_ofs);			// Z Data
	disp_lcd_G( 0,1, &disp_moji[2]);					// \

	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ

	Timer2_init();										// Timer2 Initial

	sei();												// 荞݉

	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp
	while(1){
		if(tim_10ms_buz == 0){												// TOOr̕\iuU[p^C}[pj
			tim_10ms_buz = 50;

			kesu ^= 1;														// ␳l̓_
			if(kesu == 0){													// _ł̓_̎
				wtod_05u((char *)disp_moji,cpm_to_uSv_ofs);					// Z Data
				disp_lcd_G( 0,1, &disp_moji[2]);								// \
				get_pgm_str(&str_save_exit[0]);								// vÖ̕("Save&Exit")擾
				disp_lcd_G( 6,1,disp_moji);									// \
			}else{															// _ł̖ł̎
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				if(keta <= 2){
					disp_lcd_G(keta,1, &disp_moji[9]);						// \
				}else{
					disp_lcd_G (6,1, disp_moji);							// \
				}
			}
		}
		get_sw();															//@XCb`Ԃ
		if(sw[2] != 0){														// ꂽXCb`L鎞
#ifdef		CONFIG_BACK_LIGHT_ON
			start_back_light();												// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			if((sw[2] & SW_LEFT) != 0){										// XCb`
				keta++;
				if(3 < keta){
					keta = 0;
				}
			}else if((sw[2] & SW_RIGHT) != 0){								// EXCb`
				if(keta == 0){												// POǑ
					if( ((cpm_to_uSv_ofs % 1000)/100) != 1 ){				// POǑPȊO̎
						cpm_to_uSv_ofs += 100;
					}else{
						cpm_to_uSv_ofs %= 100;
					}
				}else if(keta == 1){										// PǑ
					if( ((cpm_to_uSv_ofs % 100)/10) != 9 ){					// PǑXȊO̎
						cpm_to_uSv_ofs += 10;
					}else{
						cpm_to_uSv_ofs = ((cpm_to_uSv_ofs/100)*100)+(cpm_to_uSv_ofs % 10);
					}
				}else if(keta == 2){										// P̌
					if( (cpm_to_uSv_ofs % 10) != 9 ){						// P̌XȊO̎
						cpm_to_uSv_ofs += 1;
					}else{
						cpm_to_uSv_ofs = ((cpm_to_uSv_ofs/10)*10);
					}
				}else{														// Ȉꏊ
					cli();													// 荞ݕs

					for(i=0;i<3;i++){
						eeprom_busy_wait();
						eeprom_write_word(&eep_cpm_to_uSv_ofs[i],cpm_to_uSv_ofs);		// rZl̕ۑ
					}

					eeprom_busy_wait();
					sei();													// 荞݉
					break;
				}
				wtod_05u((char *)disp_moji,cpm_to_uSv_ofs);					// Z Data
				disp_lcd_G( 0,1, &disp_moji[2]);							// \
				kesu = 1;
			}
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();													// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}

	wait_key_off();															// Q̃XCb`Q@܂ŉiv[v

	cli();
}
//*****************************************
// guj^␳lAguo͒lArZl̑I
//*****************************************
void	proc_select_hvhosei_hvout_cpmuSv(void)
{
	unsigned char	sel=0;									//0:"HV-Moni", 1:"HV-Out", 2:"cpm->uSv", 3:"Time"
	unsigned char	kesu=1;
	unsigned char	r;

//	graph_test();											// **** GRAPH TEST ****

	while(1){
		disp_clear_lcd_G();									// Clear Display

#ifdef	NON_RTC												// RTC 
#else	//NON_RTC
		if(non_rtc == 0){
			get_pgm_str(&str_d_time[0]);					// vÖ̕("Time")擾
			disp_lcd_G( 0,3,disp_moji);						// \
		}
#endif	//NON_RTC

		get_pgm_str(&str_hv_moni[0]);						// vÖ̕("HV-Moni")擾
		disp_lcd_G( 0,0,disp_moji);							// \

		get_pgm_str(&str_hv_out[0]);						// vÖ̕("HV-Out")擾
		disp_lcd_G( 0,1,disp_moji);							// \

		get_pgm_str(&str_cpm_to_uSv[0]);					// vÖ̕("cpm->uSv")擾
		disp_lcd_G( 0,2,disp_moji);							// \

		tim_10ms_sw = 0;									// ROro߂Ƃ
		get_sw();											//@XCb`Ԃ
		tim_10ms_sw = 0;									// ROro߂Ƃ
		get_sw();											//@XCb`Ԃ
		tim_10ms_sw = 0;									// ROro߂Ƃ
		get_sw();											//@XCb`Ԃ

		Timer2_init();										// Timer2 Initial

		sei();												// 荞݉

		wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

		tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp
		while(1){
			if(tim_10ms_buz == 0){							// TOOr̕\iuU[p^C}[pj
				tim_10ms_buz = 50;

				kesu ^= 1;									// I̓_
				if(kesu == 0){								// _ł̓_̎
#ifdef	NON_RTC												// RTC 
#else	//NON_RTC
					if(non_rtc == 0){
						get_pgm_str(&str_d_time[0]);		// vÖ̕("Time")擾
						disp_lcd_G( 0,3,disp_moji);			// \
					}
#endif	//NON_RTC

					get_pgm_str(&str_hv_moni[0]);			// vÖ̕("HV-Moni")擾
					disp_lcd_G( 0,0,disp_moji);				// \

					get_pgm_str(&str_hv_out[0]);			// vÖ̕("HV-Out")擾
					disp_lcd_G( 0,1,disp_moji);				// \

					get_pgm_str(&str_cpm_to_uSv[0]);		// vÖ̕("cpm->uSv")擾
					disp_lcd_G( 0,2,disp_moji);				// \

				}else{										// _ł̖ł̎
					get_pgm_str(&str_space10[0]);			// vÖ̕("      ")擾
					if(sel == 0){
						disp_lcd_G(0,0, &disp_moji[0]);		// Xy[X\"HV-Moni"
					}else if(sel == 1){
						disp_lcd_G(0,1, &disp_moji[0]);		// Xy[X\"HV-Out"
					}else if(sel == 2){
						disp_lcd_G(0,2, &disp_moji[0]);		// Xy[X\"cpm->uSv"
					}else{
						disp_lcd_G(0,3, &disp_moji[0]);		// Xy[X\"Time"
					}
				}
			}
			get_sw();										//@XCb`Ԃ
			if(sw[2] != 0){									// ꂽXCb`L鎞
#ifdef		CONFIG_BACK_LIGHT_ON
				start_back_light();							// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
				if((sw[2] & SW_LEFT) != 0){					// XCb`
					sel++;
#ifdef	NON_RTC												// RTC 
					if(2 < sel){
						sel = 0;
					}
#else	//NON_RTC
					if(non_rtc == 0){
						if(3 < sel){
							sel = 0;
						}
					}else{
						if(2 < sel){
							sel = 0;
						}
					}
#endif	//NON_RTC

				}else if((sw[2] & SW_RIGHT) != 0){			// EXCb`
					get_pgm_str(&str_space10[0]);			// vÖ̕("      ")擾
					if(sel == 0){							// "HV-Moni"
						disp_lcd_G(0,1, &disp_moji[0]);		// Xy[X\"HV-Out"
						disp_lcd_G(0,2, &disp_moji[0]);		// Xy[X\"cpm->uSv"
						disp_lcd_G(0,3, &disp_moji[0]);		// Xy[X\"Time"
						get_pgm_str(&str_hv_moni[0]);		// vÖ̕("HV-Moni")擾
						disp_lcd_G( 0,0,disp_moji);			// \
					}else if(sel == 1){						// "HV-Out"
						disp_lcd_G(0,0, &disp_moji[0]);		// Xy[X\"HV-Moni"
						disp_lcd_G(0,2, &disp_moji[0]);		// Xy[X\"cpm->uSv"
						disp_lcd_G(0,3, &disp_moji[0]);		// Xy[X\"Time"
						get_pgm_str(&str_hv_out[0]);		// vÖ̕("HV-Out")擾
						disp_lcd_G( 0,1,disp_moji);			// \
					}else if(sel == 2){						// "cpm->uSv"
						disp_lcd_G(0,0, &disp_moji[0]);		// Xy[X\"HV-Moni"
						disp_lcd_G(0,1, &disp_moji[0]);		// Xy[X\"HV-Out"
						disp_lcd_G(0,3, &disp_moji[0]);		// Xy[X\"Time"
						get_pgm_str(&str_cpm_to_uSv[0]);	// vÖ̕("cpm->uSv")擾
						disp_lcd_G( 0,2,disp_moji);			// \
					}else if(sel == 3){						// "Time"
						disp_lcd_G(0,0, &disp_moji[0]);		// Xy[X\"HV-Moni"
						disp_lcd_G(0,1, &disp_moji[0]);		// Xy[X\"HV-Out"
						disp_lcd_G(0,2, &disp_moji[0]);		// Xy[X\"cpm->uSv"
						get_pgm_str(&str_time[0]);			// vÖ̕("Time")擾
						disp_lcd_G( 0,3,disp_moji);			// \
					}
					break;
				}
			}

#ifdef		CONFIG_BACK_LIGHT_ON
			proc_back_light();								// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

		}

		wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

		cli();

		if(sel == 0){										// "HV-Moni"
			proc_set_hv_hosei_spn_valu();					// guj^Xp␳l
			proc_set_hv_hosei_ofs_valu();					// guj^ItZbg␳l
		}else if(sel == 1){									// "HV-Volt"
			proc_set_hv_target_volt();						// guo͒l(Volt)ݒ
		}else if(sel == 2){									// "cpm->uSv"
			proc_set_cpm_uSv_span();
			proc_set_cpm_uSv_ofset();
		}else if(sel == 3){									// "Time"
			r = proc_set_rtc();								// v킹
			if(r != 0){
				rtc_error(r);
				disp_clear_lcd_G();							// Clear Display
			}
		}
	}
}

//*****************************************
// gupo͒l̒
//*****************************************
void	adj_hv_out(void)
{
	int	sa;

	sa = (int)hv_target_volt - (int)hv_moni;

	if((sa <= 1)&&(-1 <= sa)){		// Ă镨Ƃ
		in_hv_adja = 0;
	}else if(sa <= -10){
		hv_out -= 10;
		in_hv_adja = 1;
	}else if(sa < -1){
		hv_out += sa;
		in_hv_adja = 1;
	}else if(10 <= sa){
		hv_out += 10;
		in_hv_adja = 1;
	}else if(1 < sa){
		hv_out += sa;
		in_hv_adja = 1;
	}

	if(HV_OUT_COUNT_MAX < hv_out){	// HV_OUT_COUNT_MAXłƂ߂iTOOu{j
		hv_out = HV_OUT_COUNT_MAX;
	}

	if(in_hv_adja == 1){
		set_Timer1_ontime();		// Set Timer1 ON Time
	}
}


//*****************************************
// f[^̏ݒ
//*****************************************
static	void	meas_data_init(void)
{

	for(cpm_data_pos=0; cpm_data_pos < N_of_MINUTE_DATA; cpm_data_pos++){
		count_minute[cpm_data_pos] = 0xffff;
	}
	cpm_data_pos=0;

	for(cph_data_pos=0; cph_data_pos < N_of_HOUR_DATA; cph_data_pos++){
		count_hour[cph_data_pos] = 0xffffffff;
	}
	cph_data_pos=0;

	for(cpd_data_pos=0; cpd_data_pos < N_of_DAY_DATA; cpd_data_pos++){
		count_day[cpd_data_pos] = 0xffffffff;
	}
	cpd_data_pos=0;

	for(sec_data_pos=0; sec_data_pos < N_of_SEC_DATA; sec_data_pos++){
		sec_data[sec_data_pos] = 0xffff;									// Pb̃f[^US
	}
	sec_data_pos=0;

}
//*****************************************
// Pbo߂̏
//  Pbo߂ƌF́@qsbĂ鎞 rtc_1s_flg != 0 ŁA
//                          @qsbĂȂ tim2_1s_flg != 0 ōsB
//*****************************************
void	proc_1sec_passage(unsigned char init)
{
	if(init == 1){											// 
		tim_1s_a = 60;										// PbPʃ^C}[
#ifdef		CONFIG_BACK_LIGHT_ON
		start_back_light();									// obNCg̎nmX^[gs
#else		//CONFIG_BACK_LIGHT_ON
		tim_1s_back_light = 0;								// obNCgpPbPʃ^C}[
#endif		//CONFIG_BACK_LIGHT_ON
		rtc_1s_flg = 0;
		tim2_1s_flg = 0;
	}else{													// 쎞
		if(non_rtc == 0){									// qsbĂ鎞
			while(rtc_1s_flg != 0){
				if(tim_1s_a != 0){
					tim_1s_a--;								// PbPʃ^C}[@|P
				}
				rtc_1s_flg--;
			}
		}else{
			while(tim2_1s_flg != 0){
				if(tim_1s_a != 0){
					tim_1s_a--;								// PbPʃ^C}[@|P
				}
				tim2_1s_flg--;
			}
		}
	}
}
//*****************************************
// Main
//*****************************************
int	main(void)
{
	unsigned int	befor_count_minute;							// OJEg
	unsigned char	old_tim_1s_a;								// Ob
	unsigned char	i;
	unsigned char	j;
	unsigned char	old_hv_uSv_disp;
	unsigned char	disp_item = 0;
	unsigned char	disp_any_condition = 0;
	unsigned char	battry_blink=0;
	unsigned char	r;
	unsigned char	uc;
#ifdef	NON_SEEP												// SEEPROM 
#else	//NON_SEEP
	unsigned char	dw;
	unsigned char	dr;
#endif	//NON_SEEP


	delay_ms(500);												// 500mS Delay

	led_init();
	sw_init();
	DEBUG_sig_init();

#ifdef	CHECK_SW_LED_SERIAL
// ------ kdcƃXCb`̓`FbN@n ------
//  PB3: RED LED(H=ON, L=OFF)
//  PD6: Tact Switch(Yellow)
//  PD7: Tact Switch(White)
//
// -------------------------------------
//@kdĉODTbnmAODTbneeUOJԂ
//@@ǂꂩ̃XCb`ꂽkdc_铮Ł@iv[v
//
//@@vOƌ`FbN
//@@_Ŏ𑪂ė\̓gł鎖mF˂
// -------------------------------------
	delay_ms(500);												// 500mS Delay
	{
#define	LED_BLINK_COUNT	10										//  kdc̓_Ő

		unsigned char	i;

		DDRB |= (1 << DDB3);										// Port-B Bit3 : Output

		for(i=0;i<LED_BLINK_COUNT;i++){
			PORTB |= (1 << PB3);									// LED ON
			delay_ms(500);											// 500mS Delay
			PORTB &= ~(1 << PB3);									// LED OFF
			delay_ms(500);											// 500mS Delay
		}

#ifdef		PD5_DEBUG_OUT
		DDRD &= ~( (1 << DDD6) | (1 << DDD7) );						// Port-D Bit6,7 : Intput
		PORTD |= ( (1 << PD6) | (1 << PD7) );						// Port-D Bit6,7 : Pullup
#else		//PD5_DEBUG_OUT
		DDRD &= ~( (1 << DDD5) | (1 << DDD6) | (1 << DDD7) );		// Port-D Bit5,6,7 : Intput
		PORTD |= ( (1 << PD5) | (1 << PD6) | (1 << PD7) );			// Port-D Bit5,6,7 : Pullup
#endif		//PD5_DEBUG_OUT

		for(;;){
			if( ((~PIND & (1 << PIND6)) != 0)&&((~PIND & (1 << PIND7)) != 0) ){		// ]ăXCb`f[^擾@QƂĂ
				break;
			}else if( (~PIND & (1 << PIND6)) != 0){					// ]ăXCb`f[^擾
				PORTB |= (1 << PB3);								// LED ON
			}else if( (~PIND & (1 << PIND7)) != 0){					// ]ăXCb`f[^擾
				PORTB |= (1 << PB3);								// LED ON

#ifdef		PD5_DEBUG_OUT
#else		//PD5_DEBUG_OUT
			}else if( (~PIND & (1 << PIND5)) != 0){					// ]ăXCb`f[^擾
				PORTB |= (1 << PB3);								// LED ON
#endif		//PD5_DEBUG_OUT

			}else{
				PORTB &= ~(1 << PB3);								// LED OFF
			}
		}
	}
// ------ kdcƃXCb`̓`FbN@I ------

// ------ VAʐM̓`FbN@n ------
//
	uart0_pre_init();											// UART Pre_Initial

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);
	tx0_str(disp_moji);

	get_pgm_str(&str_title_1[0]);								// vÖ̕(TITLE1)擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_title_2[0]);								// vÖ̕ o[W擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_date[0]);									// vÖ̕(N)擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_time[0]);									// vÖ̕()擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_echo_check[0]);							// vÖ̕("Echo Rec + 1")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_echo_E[0]);								// vÖ̕(" Rec=E --> END")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	for(;;){
		if(rx0_char() != 0){									// Mf[^L̎
			tx0_char((unsigned char)((uart0_err_receiver + 1)&0xff));	// M
			if ((uart0_err_receiver & 0xff) == 'E'){			// fdfM̎
				break;
			}
		}
	}
	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_echo_end[0]);								// vÖ̕("Echo Check End")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

// ------ VAʐM̓`FbN@I ------
#endif	//CHECK_SW_LED_SERIAL

#ifdef	CHECK_FONT
// ****************** Font Check Start ******************
	uart0_pre_init();											// UART Pre_Initial
	DDRD &= ~( (1 << DDD6) | (1 << DDD7) );						// Port-D Bit6,7 : Intput
	PORTD |= ( (1 << PD6) | (1 << PD7) );						// Port-D Bit6,7 : Pullup
	tx0_str((unsigned char *)("Font Check Start\r\n"));
	init_lcd_G();

	for(;;){
		disp_clear_lcd_G();
		disp_lcd_G_font_check1();
		for(;;){
			if(((~PIND) & (1 << PD7)) != 0){					// ]ăXCb`f[^擾
				delay_ms(30);									// 30mS Delay
				if(((~PIND) & (1 << PD7)) != 0){				// ]ăXCb`f[^擾
					break;
				}
			}
		}
		for(;;){
			if(((~PIND) & (1 << PD7)) == 0){					// ]ăXCb`f[^擾
				delay_ms(30);									// 30mS Delay
				if(((~PIND) & (1 << PD7)) == 0){				// ]ăXCb`f[^擾
					break;
				}
			}
		}

		disp_clear_lcd_G();
		disp_lcd_G_font_check2();
		for(;;){
			if(((~PIND) & (1 << PD7)) != 0){					// ]ăXCb`f[^擾
				delay_ms(30);									// 30mS Delay
				if(((~PIND) & (1 << PD7)) != 0){				// ]ăXCb`f[^擾
					break;
				}
			}
		}
		for(;;){
			if(((~PIND) & (1 << PD7)) == 0){					// ]ăXCb`f[^擾
				delay_ms(30);									// 30mS Delay
				if(((~PIND) & (1 << PD7)) == 0){				// ]ăXCb`f[^擾
					break;
				}
			}
		}
	}
// ****************** Font Check End ********************
#endif	//CHECK_FONT



#ifdef	CHECK_BUZZER
// ****************** BUZZER Check Start ********************
	Timer0_init();
	buz2_on_off(1);
	delay_ms(500);												// 500mS Delay
	buz2_on_off(0);
	delay_ms(500);												// 500mS Delay
	buz2_on_off(1);
	delay_ms(500);												// 500mS Delay
	buz2_on_off(0);
	delay_ms(500);												// 500mS Delay
// ****************** BUZZER Check End ********************
#endif	//CHECK_BUZZER



#ifdef	CHECK_LCD
// ------ kbc̓`FbN@n ------
//
	get_pgm_str(&str_lcd_chk_start[0]);							// vÖ̕("LCD check start")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	init_lcd_G();
	disp_clear_lcd_G();

	back_light(set_back_light);									// Back Light ON/OFF

	get_pgm_str(&str_title_1[0]);								// vÖ̕(TITLE1)擾
	disp_lcd_G(0,0,disp_moji);									// \
	get_pgm_str(&str_title_2[0]);								// vÖ̕ o[W擾
	disp_lcd_G(2,1,disp_moji);									// \
	get_pgm_str(&str_date[0]);									// vÖ̕(N)擾
	disp_lcd_G(0,2,disp_moji);									// \
	get_pgm_str(&str_time[0]);									// vÖ̕()擾
	disp_lcd_G(0,3,disp_moji);									// \

	for(;;){
		back_light(1);
		PORTB |= (1 << PB3);									// LED ON
		delay_ms(1000);											// 1000mS Delay
		back_light(0);
		PORTB &= ~(1 << PB3);									// LED OFF
		delay_ms(1000);											// 1000mS Delay
	}

//
// ------ kbc̓`FbN@I ------
#endif	//CHECK_LCD



//	PRR0 |= ((1 << PRTWI) | (1 << PRTIM0) | (1 << PRSPI) | (1 << PRADC));				// sṽNbN~iR`j

//	disp_move_dir = 0;
//	disp_end_pos = 0;
//	DDRB &= ~((1 << DDB0) | (1 << DDB1) | (1 << DDB2) | (1 << DDB3) | (1 << DDB4));		// Port-B Bit0,1,2,3 & 4: Input(0,1,2,3,4 for Switch 1 -- 5)
//	PORTB = ((1 << PB0) | (1 << PB1) | (1 << PB2) | (1 << PB3) | (1 << PB4));			// Port-B Bit0,1,2,3 & 4: Pullup
//	DDRD = 0xfa;												// Port-D Bit0 & 2:Input, other:Output
//	DDRC = 0xff;												// Port-C Output

	delay_ms(200);												// 200mS Delay


#ifdef		DEBUG_TX
	uart0_pre_init();											// UART Pre_Initial
	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);
	tx0_str(disp_moji);

	get_pgm_str(&str_title_1[0]);								// vÖ̕(TITLE1)擾
	tx0_str(disp_moji);

	get_pgm_str(&str_title_2[0]);								// vÖ̕ o[W擾
	tx0_str(disp_moji);

	get_pgm_str(&str_date[0]);									// vÖ̕(N)擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);

	get_pgm_str(&str_time[0]);									// vÖ̕()擾
	tx0_str(disp_moji);

	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
	tx0_str(disp_moji);
#endif		//DEBUG_TX


	// LED
	led_on();													// LED ON
	delay_ms(500);												// 500mS Delay
	led_off();													// LED OFF

	Timer0_init();												// Timer0 Initial(for Buzzer2)
	// Buzzer
	buz2_on_off(1);												// Buzzer2 ON
	delay_ms(500);												// 500mS Delay
	buz2_on_off(0);												// Buzzer2 OFF

	uart0_pre_init();											// UART Pre_Initial
	init_lcd_G();
	disp_clear_lcd_G();

#ifdef		CONFIG_BACK_LIGHT_ON
	back_light(1);												// obNCg_
#endif		//CONFIG_BACK_LIGHT_ON
	// Title
	get_pgm_str(&str_title_1[0]);								// vÖ̕(TITLE1)擾
	disp_lcd_G(0, 0, disp_moji);								// display Dot Matrix LCD Up Side
	get_pgm_str(&str_title_2[0]);								// vÖ̕ o[W擾
	disp_lcd_G(0, 1, disp_moji);								// display Dot Matrix LCD Down Side
#ifdef		ONE_BATTERY
	get_pgm_str(&str_title_3[0]);								// vÖ̕ o[W擾
	disp_lcd_G(0, 2, disp_moji);								// display Dot Matrix LCD Down Side
#endif
	tx_title();													// ^CgAo[WM

	get_pgm_str(&str_date[0]);									// vÖ̕(N)擾
	disp_lcd_G(0,6,disp_moji);									// \
	get_pgm_str(&str_time[0]);									// vÖ̕()擾
	disp_lcd_G(0,7,disp_moji);									// \
	tx_make_data();												// vO쐬NM

	delay_ms(2000);												// 2000mS Delay
	disp_clear_lcd_G();											// Clear Display

// POPU̕\
//	disp_lcd_10x16_G(0, 0, (unsigned char *)"0.12");
//	disp_lcd_10x16_G(4, 1, (unsigned char *)"3/45");
//	disp_lcd_10x16_G(6, 2, (unsigned char *)"6:78");
//	disp_lcd_10x16_G(5, 3, (unsigned char *)"9" "\01\02");
//	delay_ms(4000);												// 2000mS Delay
//	disp_clear_lcd_G();											// Clear Display


	load_back_light_mode();										// obNCg[h̓ǂݏo
	load_buz_on_off();											// uU[nm^nee̓ǂݏo
	ad67_init();												// A/D 6&7 Initial
	init_cpm_to_uSv();											// rZl̏

#ifdef		CONFIG_BACK_LIGHT_ON
	proc_back_light();											// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

#ifdef	NON_RTC													// RTC 
	non_rtc = 1;												// Ȍqsb͓ǂݏoȂ
	rtc_read_data_clear();										// RTC ǂݏof[^NA
#else	//NON_RTC
	r = rtc_init();												//  qsb̏ݒ
	if(r != 0){
		rtc_error(r);
		disp_clear_lcd_G();										// Clear Display
	}
#endif	//NON_RTC

#ifdef		CONFIG_BACK_LIGHT_ON
	start_back_light();											// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON

#ifdef	NON_RTC													// RTC 
#else	//NON_RTC
	if(non_rtc == 0){
		r = rtc_read();											// RTC ǂݏo
		if(r != 0){
			rtc_error(r);
			disp_clear_lcd_G();									// Clear Display
		}
	}
#endif	//NON_RTC

	if(non_rtc == 0){
		if((gRTC_sec & 0x80)!= 0){								// qsb̓d
			r = proc_set_rtc();									// v킹
			if(r != 0){
				rtc_error(r);
			}
			disp_clear_lcd_G();									// Clear Display
		}
	}

#ifdef	NON_SEEP													// SEEPROM 
#else	//NON_SEEP
	DEBUG_sig_on();
	r = seep_read_1(0x0001, &dw);								// Serial EEPROM Read
	if(r != 0){
		seep_error1(r);
		disp_clear_lcd_G();										// Clear Display
	}
	dw++;
	r = seep_write_1(0x0001, &dw);								// Serial EEPROM Read
	if(r != 0){
		seep_error1(r);
		disp_clear_lcd_G();										// Clear Display
	}
	r = seep_read_1(0x0001, &dr);								// Serial EEPROM Read
	if(r != 0){
		seep_error1(r);
		disp_clear_lcd_G();										// Clear Display
	}
	if(dw != dr){
		seep_error2(dw, dr);
		disp_clear_lcd_G();										// Clear Display
	}
#endif	//NON_SEEP


	graph_init();												// Ot ݒ

	if( (PIND & (SW_LEFT | SW_RIGHT)) == 0 ){					// Left SW & Right SW nm
		delay_ms(100);											// 100mS Delay
		if((PIND & (SW_LEFT | SW_RIGHT)) == 0){					// Left SW & Right SW nm
			proc_select_hvhosei_hvout_cpmuSv();					// guj^␳lAguo͒lArZl̑I
		}
	}else{
		proc_disp_save_data();									// ۑf[^̕\
		proc_buz_enable();										// uU[̂nm^neeݒ

		if(non_rtc == 0){
			disp_clear_lcd_G();										// Clear Display
			r = rtc_read();											// RTC ǂݏo
			if(r != 0){
				rtc_error(r);
			}else{
				disp_date_time_large();								// v@̑傫ȕ\
				j = (gRTC_sec & 0x7f);								// b
				get_pgm_str(&str_clock_adjust[0]);					// vÖ̕ "R-SW Clock Adjust" 擾
				disp_lcd_G( 1,5,disp_moji);							// \
				get_pgm_str(&str_escape_this[0]);					// vÖ̕ "L-SW Escape This" 擾
				disp_lcd_G( 1,6,disp_moji);							// \
				uc = 5;
				for(i=0;i<50;i++){
					delay_ms(200);									// 100mS Delay
					r = rtc_read();									// RTC ǂݏo
					if(r != 0){
						rtc_error(r);
						break;
					}
					if (j != (gRTC_sec & 0x7f)){					// bω
						disp_date_time_large();						// v@̑傫ȕ\
						j = (gRTC_sec & 0x7f);						// b
					}
					if( (~PIND & SW_RIGHT) != 0 ){					// Right SW nm
						delay_ms(100);								// 100mS Delay
						if((~PIND & SW_RIGHT) != 0){				// Right SW nm
#ifdef		CONFIG_BACK_LIGHT_ON
							start_back_light();						// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
							r = proc_set_rtc();						// v킹
							if(r != 0){
								rtc_error(r);
								disp_clear_lcd_G();					// Clear Display
								break;
							}else{
								disp_clear_lcd_G();					// Clear Display
								disp_date_time_large();				// v@̑傫ȕ\
								get_pgm_str(&str_clock_adjust[0]);	// vÖ̕ "R-SW Clock Adjust" 擾
								disp_lcd_G( 1,5,disp_moji);			// \
								get_pgm_str(&str_escape_this[0]);	// vÖ̕ "L-SW Escape This" 擾
								disp_lcd_G( 1,6,disp_moji);			// \
								i = 0;
								j = (gRTC_sec & 0x7f);				// b
							}
						}
					}
					if( (~PIND & SW_LEFT) != 0 ){					// Left SW nm
						delay_ms(100);								// 100mS Delay
						if((~PIND & SW_LEFT) != 0){					// Left SW nm
#ifdef		CONFIG_BACK_LIGHT_ON
							start_back_light();						// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
							break;
						}
					}

					uc--;
					if(uc == 0){
						uc = 5;
						if(tim_1s_back_light != 0){
							tim_1s_back_light--;
						}
					}
#ifdef		CONFIG_BACK_LIGHT_ON
					proc_back_light();								// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

				}
			}
		}
	}

	Timer2_init();												// Timer2 Initial
	Timer1_init(0);												// Timer1 Initial
	HV_on();													// High Volt ON

#ifdef		CONFIG_BACK_LIGHT_ON
	start_back_light();											// obNCg̎nmX^[gs
	proc_back_light();											// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	disp_clear_lcd_G();											// Clear Display
	get_pgm_str(&str_hv_monitor[0]);							// vÖ̕("HV Monitor")擾
	disp_lcd_G( 0,0,disp_moji);									// \
	if(buz_on == 1){
		get_pgm_str(&str_buz_enable[0]);						// vÖ̕("Buzzer Enable")擾
	}else{
		get_pgm_str(&str_buz_disable[0]);						// vÖ̕("Buzzer Disable")擾
	}
	disp_lcd_G( 0,2,disp_moji);									// \

	if(back_light_mode == 2){									// 	nm̎
		get_pgm_str(&str_back_light_on[0]);						// vÖ̕("Back Light ON  ")擾
	}else if(back_light_mode == 1){								//@`tsn̎
		get_pgm_str(&str_back_light_auto[0]);					// vÖ̕("Back Light AUTO")擾
	}else{														//  nee̎
		get_pgm_str(&str_back_light_off[0]);					// vÖ̕("Back Light OFF ")擾
	}
	disp_lcd_G( 0,4,disp_moji);									// \

//	tx_setting_value();											// ݒWM

	for(i=0;i<8;i++){
		for(j=0;j<100;j++){
			ad67_set_data();									// A/D 6&7 Set A/D data to Data Buffer
			delay_ms(10);										// 10mS Delay
		}
		disp_hv_moni(12,  0);									// guj^l̕\
	}

	disp_clear_lcd_G();
	befor_count_minute = 0xffff;
	old_tim_1s_a = 0xff;
	tim_1minute = 60;
	tim_1hour = 24;
	old_hv_uSv_disp = 0xff;
	hv_uSv_disp = 0;

	meas_data_init();											// f[^̏ݒ
	disp_buz_symble();											// uU[̂nm^nee\
	set_sleep_mode(SLEEP_MODE_IDLE);							// X[vFACh[h
	count_init();												// Count Initial
	proc_1sec_passage(1);										// Pbo߂̏ij
	sei();														// 荞݉
	for(;;){
		disp_item = 0;
		disp_any_condition = 0;
		//@XCb`
		get_sw();												//@XCb`Ԃ
		if(sw[2] != 0){											// ꂽXCb`L鎞
			if((sw[2] & SW_LEFT) != 0){							// XCb`nm̎
				hv_uSv_disp++;									// ʂ̈ڍs
				if(6 < hv_uSv_disp){							// V
					hv_uSv_disp = 0;
				}
			}

			if((sw[2] & SW_RIGHT) != 0){						// EXCb`nm̎
				buz_on ^= 1;
				disp_buz_symble();								// uU[̂nm^nee\
			}

			start_back_light();									// obNCg̎nmX^[gs
		}

		if(befor_count_minute != count_minute_now){					// JE^lω
			befor_count_minute = count_minute_now;
			count_minute[cpm_data_pos] = befor_count_minute;
			// JE^\
			disp_item |= DISP_MEAS_NOW_01;							// ̒l\
		}
		proc_1sec_passage(0);										// Pbo߂̏ij
		if(tim_1s_a == 0){											// UObo߂
			count_minute_now = 0;
			tim_1s_a = 60;
			tim_1minute--;											// 
			if(non_rtc == 0){
				r=rtc_read();										// RTC ǂݏo
				if(r != 0){											// ǂݏoG[̎
					non_rtc = 1;									// Ȍqsb͓ǂݏoȂ
				}
			}
			convert_date_time();									// unsigned long ̒lɕϊ
			// JE^\
			if(count_hour[cph_data_pos] == 0xffffffff){				// PԖ̃JEg܂gĂȂ
				count_hour[cph_data_pos] = 0;						// x[ɂ
			}
			count_hour[cph_data_pos] += count_minute[cpm_data_pos];	// PԖ̃JEgɑ
			save_minute_data(count_minute[cpm_data_pos]);			// PԖf[^̕ۑ
			cpm_data_pos = get_next_num_cpm();						// ̍ۑĂ鏊̂ЂƂ̔ԍ߂
			count_minute[cpm_data_pos] = 0;
			disp_item |= DISP_MEAS_CPM_02;							// Ô̒l\
			disp_item |= DISP_MEAS_CPH_03;							// ̂̒l\
			if(tim_1minute == 0){									// UOo߂
				tim_1minute = 60;
				if(count_day[cpd_data_pos] == 0xffffffff){			// P̃JEg܂gĂȂ
					count_day[cpd_data_pos] = 0;					// x[ɂ
				}
				count_day[cpd_data_pos] += count_hour[cph_data_pos];	// P̃JEgɑ
				save_hour_data(count_hour[cph_data_pos]);			// PԖf[^̕ۑ
				cph_data_pos = get_next_num_cph();					// ̍ۑĂ鏊̂ЂƂ̔ԍ߂
				count_hour[cph_data_pos] = 0;
				tim_1hour--;
				disp_item |= DISP_MEAS_CPD_04;						// ̂̒l\
				if(tim_1hour == 0){									// QSԌo߂
					tim_1hour = 24;
					save_day_data(count_day[cpd_data_pos]);			// Pf[^̕ۑ
					cpd_data_pos = get_next_num_cpd();				// ̍ۑĂ鏊̂ЂƂ̔ԍ߂
					count_day[cpd_data_pos] = 0;
					disp_item |= DISP_MEAS_CPD_07;					// Ŝ̒l\
				}
			}
			old_hv_uSv_disp = 0xff;
		}

		// LED
		if(tim_10ms_led != 0){
			led_on();											// LED ON
		}else{
			led_off();											// LED OFF
		}

		// Buzzer
		if((tim_10ms_buz != 0)&&(buz_on == 1)){
			buz2_on_off(1);										// Buzzer ON
		}else{
			buz2_on_off(0);										// Buzzer OFF
		}

		if(old_hv_uSv_disp != hv_uSv_disp){						// gudAr\  ω
			old_hv_uSv_disp = hv_uSv_disp;
			if(hv_uSv_disp == 0){
				disp_meas_title();								// 荀ڂ̃^Cg\iȂj
				disp_item |= (DISP_MEAS_SEC_00 | DISP_MEAS_NOW_01 | DISP_MEAS_CPM_02 | DISP_MEAS_CPH_03 | DISP_MEAS_CPD_04 | DISP_MEAS_HV_05 | DISP_MEAS_BAT_06 | DISP_MEAS_CPD_07);
				disp_any_condition = 1;							// Iɕ\
			}else if(hv_uSv_disp == 1){
				disp_meas_title_count();						// 荀ڂ̃^Cg\iJEgj
				disp_item |= (DISP_MEAS_SEC_00 | DISP_MEAS_NOW_01 | DISP_MEAS_CPM_02 | DISP_MEAS_CPH_03 | DISP_MEAS_CPD_04 | DISP_MEAS_HV_05 | DISP_MEAS_BAT_06 | DISP_MEAS_CPD_07);
				disp_any_condition = 1;							// Iɕ\
			}else if(hv_uSv_disp == 2){
				disp_meas_title_usv_h();						// 荀ڂ̃^Cg\ir^j
				disp_item |= (DISP_MEAS_SEC_00 | DISP_MEAS_NOW_01 | DISP_MEAS_CPM_02 | DISP_MEAS_CPH_03 | DISP_MEAS_CPD_04 | DISP_MEAS_HV_05 | DISP_MEAS_BAT_06 | DISP_MEAS_CPD_07);
				disp_any_condition = 1;							// Iɕ\
			}else if(hv_uSv_disp == 3){							// cpm
				disp_item |= (DISP_MEAS_SEC_00 | DISP_MEAS_NOW_01 | DISP_MEAS_CPM_02 | DISP_MEAS_CPH_03 | DISP_MEAS_CPD_04 | DISP_MEAS_HV_05 | DISP_MEAS_BAT_06 | DISP_MEAS_CPD_07);
				disp_any_condition = 1;							// Iɕ\
			}else if(hv_uSv_disp == 4){							// cph
				disp_item |= (DISP_MEAS_SEC_00 | DISP_MEAS_NOW_01 | DISP_MEAS_CPM_02 | DISP_MEAS_CPH_03 | DISP_MEAS_CPD_04 | DISP_MEAS_HV_05 | DISP_MEAS_BAT_06 | DISP_MEAS_CPD_07);
				disp_any_condition = 1;							// Iɕ\
			}else if(hv_uSv_disp == 5){							// cpd
				disp_item |= (DISP_MEAS_SEC_00 | DISP_MEAS_NOW_01 | DISP_MEAS_CPM_02 | DISP_MEAS_CPH_03 | DISP_MEAS_CPD_04 | DISP_MEAS_HV_05 | DISP_MEAS_BAT_06 | DISP_MEAS_CPD_07);
				disp_any_condition = 1;							// Iɕ\
			}else{
				disp_meas_title_full();							// 荀ڂ̃^Cg\ij
				disp_item |= (DISP_MEAS_SEC_00 | DISP_MEAS_NOW_01 | DISP_MEAS_CPM_02 | DISP_MEAS_CPH_03 | DISP_MEAS_CPD_04 | DISP_MEAS_HV_05 | DISP_MEAS_BAT_06 | DISP_MEAS_CPD_07);
				disp_any_condition = 1;							// Iɕ\
			}

		}

		if(old_tim_1s_a != tim_1s_a){							// bω
			old_tim_1s_a = tim_1s_a;
			disp_item |= DISP_MEAS_SEC_00;						// ̒l\
			disp_item |= DISP_MEAS_NOW_01;						// ̒l\
			disp_item |= DISP_MEAS_HV_05;						// ̒l\
			disp_item |= DISP_MEAS_BAT_06;						// ̒l\
			get_hv_moni();										// guj^l(Volt)̎擾(hv_moni ɓ)
			adj_hv_out();										// gupo͒l̒

			proc_back_light();									// obNCĝnm^nees

			// obe[ՌxuN
			get_bat_moni();										// obej^l(Volt)̎擾(bat_moni ɓ)
			if((battry_blink == 0) && (bat_moni <= BATTERY_LOW_DOWN)){
				battry_blink=1;
			}else if((battry_blink == 1) && (BATTERY_LOW_UP <= bat_moni)){
				battry_blink=0;
			}
			if(battry_blink == 1){
				tim_10ms_battery = 50;							// obeuNpPOrPʃ^C}[
				disp_bat_title( 0, 7, 1);						// obeږ̕\
			}else{
				tim_10ms_battery = 0;							// obeuNpPOrPʃ^C}[
			}

			sec_data[sec_data_pos] = count_sec;					// Pb̃f[^𕽋ϒlpɕۑ
			count_sec = 0;
			sec_data_pos++;
			sec_data_pos &= (N_of_SEC_DATA - 1);
		}

		if(hv_uSv_disp == 0){
			disp_meas_data( &disp_item, disp_any_condition);		// 荀ڂ̕\iȂj
		}else if(hv_uSv_disp == 1){
			disp_meas_data_count( &disp_item, disp_any_condition);	// 荀ڂ̕\iJEgj
		}else if(hv_uSv_disp == 2){
			disp_meas_data_usv_h( &disp_item, disp_any_condition);	// 荀ڂ̕\ir^j
		}else if(hv_uSv_disp == 3){
			disp_cpm_graph( &disp_item, disp_any_condition);		// ̃Ot
		}else if(hv_uSv_disp == 4){
			disp_cph_graph( &disp_item, disp_any_condition);		// ̃Ot
		}else if(hv_uSv_disp == 5){
			disp_cpd_graph( &disp_item, disp_any_condition);		// ̃Ot
		}else if(hv_uSv_disp == 6){
			disp_meas_data_full( &disp_item, disp_any_condition);	// 荀ڂ̕\ij
		}


		if(tim_10ms_battery_zero_now == 1){							// obeuNp̃^C}[OɂȂ
			tim_10ms_battery_zero_now = 0;							// obeuNp̃^C}[OɂȂ
			disp_bat_title( 0, 7, 0);								// obeږ
		}

		sleep_mode();												// X[vڍs
	}

}

//*****************************************
// CR & LF Set to disp_moji[]
//*****************************************
void	get_cr_lf(void)
{
	get_pgm_str(&str_crlf[0]);									// vÖ̕("\r\n")擾
}
//*****************************************
// Title Set to disp_moji[]
//*****************************************
void	get_title(void)
{
	get_pgm_str(&str_title_1[0]);								// vÖ̕(TITLE1)擾
}
