//*****************************************
// AVR ATmega644P Geiger Counter
// CPU Clock:8MHz,16NHz,18.432MHz or 20MHz(Compile Option)
// File Name:Rtc.c
//  Use UART0
// KCK[JE^[p
//   iq[Yf[^@is`fgpȂAȂAwIV[^(8MHz)Aɂj
//   i`FbN͂rohdmj
//
//  PC0(SCL): TWI-SCL
//  PC1(SDA): TWI-SDA
//
//  C:\WinAVR-20100110\doc\avr-libc\avr-libc-user-manual.pdf ɊeCN[ht@C̐
//
//  2011/09/02 New  Taishi ATmega644P(J308)
//  2011/10/22 Modify for LND712 by  Taishi
//  2011/10/28 Modify for SBM-20 by  Taishi
//  2011/11/08 Modify for LND712 by  Taishi
//  2011/11/12 Modify for SBM-20 by  Taishi
//  2011/11/12 Modify for J-308  by  Taishi
//  2011/11/24 Modify for All Model  Taishi
//  2011/12/12 Modify for All Model  Taishi(Ver 1.03A) 
//*****************************************

#include	<avr/interrupt.h>
#include	<avr/io.h>
#include	<compat/twi.h>
#include	<avr/pgmspace.h>

#include	"AVR_ATmega644_Geiger.h"
#include	"Mega_Twi.h"

#include	"LCD.h"
#include	"Utility.h"
#include	"Timer.h"

#include	"Rtc.h"


unsigned char	gRTC_sec;				// qsb b̃f[^ (BCD 0--59)
unsigned char	gRTC_min;				// qsb ̃f[^ (BCD 0--59)
unsigned char	gRTC_hou;				// qsb ̃f[^ (BCD 0--23j
unsigned char	gRTC_wday;				// qsb j̃f[^ (BCD 1--7)
unsigned char	gRTC_day;				// qsb ̃f[^ (BCD 1--31)
unsigned char	gRTC_mon;				// qsb ̃f[^ (BCD 1--12j
unsigned char	gRTC_year;				// qsb Ñf[^ (BCD 0--99)
unsigned char	gRTC_control;			// qsb Rg[̃f[^
unsigned char	gCount_sqw;				// rpvM̃JEg

unsigned long	gDate_Time;				// unsigned long ̒l(2011/12/31 23:59:59  111231235959 ɂȂ)
unsigned char	rtc_1s_flg;				// qsbĂ鎞̂Pboߗp

static	unsigned char	sRTC_second;	// qsb b̃f[^ (BCD 0--59)
static	unsigned char	sRTC_minute;	// qsb ̃f[^ (BCD 0--59)
static	unsigned char	sRTC_hour;		// qsb ̃f[^ (BCD 0--23j
static	unsigned char	sRTC_wday;		// qsb j̃f[^ (BCD 1--7)
static	unsigned char	sRTC_day;		// qsb ̃f[^ (BCD 1--31)
static	unsigned char	sRTC_month;		// qsb ̃f[^ (BCD 1--12j
static	unsigned char	sRTC_year;		// qsb Ñf[^ (BCD 0--99)
static	unsigned char	sRTC_control;	// qsb Rg[̃f[^


//***************************
// RTC Initial
//  qsb̏ݒ
//***************************
unsigned char	rtc_init(void)
{
	unsigned char	r = 0;

	twi_init();


	// Pbo͐ݒ
//  PD2(INT0): Pulse In from RTC Square Wave Signal(1Hz,4kHz,8kHz,32kHz)
	DDRD &= ~(1 << DDD2);					// Port-D Bit2 : Intput

	r = rtc_control_read();					// RTC Rg[f[^ǂݏo
	if(r != 0){
		return(r);
	}
	if(gRTC_control == RTC_CONTROL_SQWE){	// Pb̕`͏o͐ݒ̎
		;									// Ȃ
	}else{									// Pb̕`͏o͈ȊO̎
		gRTC_control = RTC_CONTROL_SQWE;	// Pb̕`͏o͐ݒɂ
		r = rtc_control_write();			// RTC Rg[f[^
		if(r != 0){
			return(r);
		}
	}

	// INT0 Interrupt Initial
	EICRA |=  (1 << ISC01);					// INT0 Falling Edge Interrupt
	EICRA &= ~(1 << ISC00);					// INT0 Falling Edge Interrupt
	EIMSK |= (1 << INT0);					// INT0 Interrupt Enable

	return(0);
}

//***************************
// RTC ǂݏof[^NA
//***************************
void	rtc_read_data_clear(void)
{
	gRTC_sec = 0;						// qsb b̃f[^ (BCD 0--59)
	gRTC_min = 0;						// qsb ̃f[^ (BCD 0--59)
	gRTC_hou = 0;						// qsb ̃f[^ (BCD 0--23j
	gRTC_wday = 0;						// qsb j̃f[^ (BCD 1--7)
	gRTC_day = 0;						// qsb ̃f[^ (BCD 1--31)
	gRTC_mon = 0;						// qsb ̃f[^ (BCD 1--12j
	gRTC_year = 0;						// qsb Ñf[^ (BCD 0--99)
}

//***************************
// RTC ǂݏo
//  ǂݏof[^͈ȉ̕ϐɓ
//	unsigned char	gRTC_sec;				// qsb b̃f[^ (BCD 0--59)
//	unsigned char	gRTC_min;				// qsb ̃f[^ (BCD 0--59)
//	unsigned char	gRTC_hou;				// qsb ̃f[^ (BCD 0--23j
//	unsigned char	gRTC_day;				// qsb j̃f[^ (BCD 1--7)
//	unsigned char	gRTC_date;				// qsb ̃f[^ (BCD 1--31)
//	unsigned char	gRTC_mon;				// qsb ̃f[^ (BCD 1--12j
//	unsigned char	gRTC_year;				// qsb Ñf[^ (BCD 0--99)
//***************************
unsigned char rtc_read(void)
{
	unsigned char	data;
	unsigned char	r;

	if( non_rtc != 0){
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(1);
	}

	r = twi_start(DS1307_ID,DS1307_ADDR,TW_WRITE);	// TWI Jn foCXhcƃfoCXAhXƂvqhsd
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_START_TW_WRITE;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	r = twi_write(0x00);							// TWI  AhX
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	twi_stop();

	r = twi_start(DS1307_ID,DS1307_ADDR,TW_READ);	// TWI Jn foCXhcƃfoCXAhXƂqd`c
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_START_TW_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	r = twi_read(&data,ACK);						// TWI ǂݏo
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	sRTC_second=data;
	r = twi_read(&data,ACK);						// TWI ǂݏo
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	sRTC_minute=data;
	r = twi_read(&data,ACK);						// TWI ǂݏo
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	sRTC_hour=data;
	r = twi_read(&data,ACK);						// TWI ǂݏo
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	sRTC_wday=data;
	r = twi_read(&data,ACK);						// TWI ǂݏo
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	sRTC_day=data;
	r = twi_read(&data,ACK);						// TWI ǂݏo
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	sRTC_month=data;
	r = twi_read(&data,ACK);						// TWI ǂݏo
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	sRTC_year=data;
	r = twi_read(&data,NACK);						// TWI ǂݏo Ō
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		rtc_read_data_clear();						// RTC ǂݏof[^NA
		return(r);
	}
	sRTC_control=data;

	twi_stop();

	gRTC_sec = sRTC_second;						// qsb b̃f[^ (BCD 0--59)
	gRTC_min = sRTC_minute;						// qsb ̃f[^ (BCD 0--59)
	gRTC_hou = sRTC_hour;						// qsb ̃f[^ (BCD 0--23j
	gRTC_wday = sRTC_wday;						// qsb j̃f[^ (BCD 1--7)
	gRTC_day = sRTC_day;						// qsb ̃f[^ (BCD 1--31)
	gRTC_mon = sRTC_month;						// qsb ̃f[^ (BCD 1--12j
	gRTC_year = sRTC_year;						// qsb Ñf[^ (BCD 0--99)

	return(r);
}

//***************************
// RTC 
//  ݃f[^͈ȉ̕ϐɓĂ镨Ƃ
//	unsigned char	gRTC_sec;				// qsb b̃f[^ (BCD 0--59)
//	unsigned char	gRTC_min;				// qsb ̃f[^ (BCD 0--59)
//	unsigned char	gRTC_hou;				// qsb ̃f[^ (BCD 0--23j
//	unsigned char	gRTC_wday;				// qsb j̃f[^ (BCD 1--7)
//	unsigned char	gRTC_day;				// qsb ̃f[^ (BCD 1--31)
//	unsigned char	gRTC_mon;				// qsb ̃f[^ (BCD 1--12j
//	unsigned char	gRTC_year;				// qsb Ñf[^ (BCD 0--99)
//***************************
unsigned char	rtc_write(void)
{
	unsigned char	r;

	if( non_rtc != 0){
		return(1);
	}

	sRTC_second = gRTC_sec;						// qsb b̃f[^ (BCD 0--59)
	sRTC_minute = gRTC_min;						// qsb ̃f[^ (BCD 0--59)
	sRTC_hour = gRTC_hou;						// qsb ̃f[^ (BCD 0--23j
	sRTC_wday = gRTC_wday;						// qsb j̃f[^ (BCD 1--7)
	sRTC_day = gRTC_day;						// qsb ̃f[^ (BCD 1--31)
	sRTC_month = gRTC_mon;						// qsb ̃f[^ (BCD 1--12j
	sRTC_year = gRTC_year;						// qsb Ñf[^ (BCD 0--99)

	sRTC_second &= 0x7F;
	r=twi_start(DS1307_ID,DS1307_ADDR,TW_WRITE);	// TWI Jn foCXhcƃfoCXAhXƂvqhsd
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_START_TW_WRITE;
		return(r);
	}
	r=twi_write(0x00);								// TWI  AhX
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	r=twi_write(sRTC_second);						// b̃f[^ (BCD 0--59)
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	r=twi_write(sRTC_minute);						// ̃f[^ (BCD 0--59)
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	r=twi_write(sRTC_hour);							// ̃f[^ (BCD 0--23j
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	r=twi_write(sRTC_wday);							// j̃f[^ (BCD 1--7)
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	r=twi_write(sRTC_day);							// ̃f[^ (BCD 1--31)
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	r=twi_write(sRTC_month);						// ̃f[^ (BCD 1--12j
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	r=twi_write(sRTC_year);							// Ñf[^ (BCD 0--99)
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}

	twi_stop();

	return(r);
}

//***************************
// RTC Rg[f[^ǂݏo
//  ǂݏof[^ gRTC_control ɓ
//
//	DS1307_ID		0xD0	// I2C DS1307 Device Identifier
//	DS1307_ADDR		0x00	// I2C DS1307 Device Address
//  TW_READ			1
//  TW_WRITE		0
//
//***************************
unsigned char	rtc_control_read(void)
{
	unsigned char	data;
	unsigned char	r;

	if( non_rtc != 0){
		return(1);
	}

	r = twi_start(DS1307_ID,DS1307_ADDR,TW_WRITE);	// TWI Jn foCXhcƃfoCXAhXƂvqhsd
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_START_TW_WRITE;
		return(r);
	}
	r = twi_write(0x07);							// TWI  AhX
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	twi_stop();

	r = twi_start(DS1307_ID,DS1307_ADDR,TW_READ);	// TWI Jn foCXhcƃfoCXAhXƂqd`c
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_START_TW_READ;
		return(r);
	}
	r = twi_read(&data,NACK);						// TWI ǂݏo Ō NACK=0
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_READ;
		return(r);
	}
	sRTC_control = data;
	gRTC_control = data;							// qsb Rg[̃f[^

	twi_stop();

	return(0);
}
//***************************
// RTC Rg[f[^
//  ݃f[^ unsigned char gRTC_control ɓĂ镨Ƃ
//***************************
unsigned char	rtc_control_write(void)
{
	unsigned char	r;

	if( non_rtc != 0){
		return(1);
	}

	sRTC_control = gRTC_control;				// qsb Rg[̃f[^

	r = twi_start(DS1307_ID,DS1307_ADDR,TW_WRITE);	// TWI Jn foCXhcƃfoCXAhXƂvqhsd
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_START_TW_WRITE;
		return(r);
	}
	r = twi_write(0x07);							// TWI  AhX
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}
	r = twi_write(sRTC_control);					// Rg[f[^
	if(r != 0){										// G[̎
		r = RTC_ERR_TWI_WRITE;
		return(r);
	}

	twi_stop();

	return(r);
}

//*****************************************
// v@̑傫ȕ\
// ߂l@Ȃ
//*****************************************
void	disp_date_time_large(void)
{
	gRTC_mon &= 0x1f;									// 
	gRTC_day &= 0x3f;									// 
	gRTC_hou &= 0x3f;									// 
	gRTC_min &= 0x7f;									// 
	gRTC_sec &= 0x7f;									// b

	disp_moji[0] = '2';
	disp_moji[1] = '0';
	wtod_02x((char *)(disp_moji+2), gRTC_year);
	disp_lcd_10x16_G( 0,0,disp_moji);					// N \
	disp_one_10x16_char_lcd_G( 4, 0, '/');
	wtod_02x((char *)disp_moji, gRTC_mon );
	disp_lcd_10x16_G( 5,0,disp_moji);					//  \
	disp_one_10x16_char_lcd_G( 7, 0, '/');
	wtod_02x((char *)disp_moji, gRTC_day );
	disp_lcd_10x16_G( 8,0,disp_moji);					//  \
	wtod_02x((char *)disp_moji, gRTC_hou );
	disp_lcd_10x16_G( 1,1,disp_moji);					//  \
	disp_one_10x16_char_lcd_G( 3, 1, ':');
	wtod_02x((char *)disp_moji, gRTC_min & 0x7f );
	disp_lcd_10x16_G( 4,1,disp_moji);					//  \
	disp_one_10x16_char_lcd_G( 6, 1, ':');
	wtod_02x((char *)disp_moji, gRTC_sec );
	disp_lcd_10x16_G( 7,1,disp_moji);					// b \

}
//*****************************************
// v킹
// ߂l@OFɂqsbǂ߂
// @@@@PFɂqsbǂ߂Ȃ
//*****************************************
unsigned char	str_date_time[] PROGMEM    = {"Set Time"};	// "Set Time"

unsigned char	proc_set_rtc(void)
{
	unsigned char	keta=0;								// 0:N10̌, 1:N1̌, 2:10̌, 3:1̌, 4:10̌, 5:1̌,
														// 6:10̌, 7:1̌, 8:10̌, 9:1̌, 10:b10̌, 11:b1̌, 12: Save & Exit, 13: Exit, 
	unsigned char	kesu=1;
	unsigned char	r;

	r = rtc_read();										// RTC ǂݏo
	if(r != 0){
		return(r);
	}

	gRTC_mon &= 0x1f;									// 
	gRTC_day &= 0x3f;									// 
	gRTC_hou &= 0x3f;									// 
	gRTC_min &= 0x7f;									// 
	gRTC_sec &= 0x7f;									// b

	disp_clear_lcd_G();									// Clear Display
	get_pgm_str(&str_date_time[0]);						// vÖ̕("Set Time")擾
	disp_lcd_G( 0,0,disp_moji);							// \
	get_pgm_str(&str_save_exit[0]);						// vÖ̕("Save&Exit")擾
	disp_lcd_G( 0,2,disp_moji);							// \
	get_pgm_str(&str_exit[0]);							// vÖ̕("Exit")擾
	disp_lcd_G( 0,3,disp_moji);							// \

	disp_moji[0] = '2';
	disp_moji[1] = '0';
	wtod_02x((char *)(disp_moji+2), gRTC_year);
	disp_lcd_G( 0,1,disp_moji);							// N \
	disp_one_char_lcd_G( 4, 1, '/');
	wtod_02x((char *)disp_moji, gRTC_mon );
	disp_lcd_G( 5,1,disp_moji);							//  \
	disp_one_char_lcd_G( 7, 1, '/');
	wtod_02x((char *)disp_moji, gRTC_day );
	disp_lcd_G( 8,1,disp_moji);							//  \
	disp_one_char_lcd_G(10, 1, ' ');
	wtod_02x((char *)disp_moji, gRTC_hou );
	disp_lcd_G(11,1,disp_moji);							//  \
	disp_one_char_lcd_G(13, 1, ':');
	wtod_02x((char *)disp_moji, gRTC_min & 0x7f );
	disp_lcd_G(14,1,disp_moji);							//  \
	disp_one_char_lcd_G(16, 1, ':');
	wtod_02x((char *)disp_moji, gRTC_sec );
	disp_lcd_G(17,1,disp_moji);							// b \


	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ
	tim_10ms_sw = 0;									// ROro߂Ƃ
	get_sw();											//@XCb`Ԃ

	Timer2_init();										// Timer2 Initial

	sei();												// 荞݉

	wait_key_off();										// Q̃XCb`Q@܂ŉiv[v

	tim_10ms_buz = 0;									// uU[pPOrPʃ^C}[\Ԋuɗp
	while(1){
		if(tim_10ms_buz == 0){												// TOOr̕\iuU[p^C}[pj
			tim_10ms_buz = 50;

			kesu ^= 1;														// ␳l̓_
			if(kesu == 0){													// _ł̓_̎
				wtod_02x((char *)disp_moji, gRTC_year);
				disp_lcd_G( 2,1,disp_moji);									// N \
				wtod_02x((char *)disp_moji, (gRTC_mon & 0x1f) );
				disp_lcd_G( 5,1,disp_moji);									//  \
				wtod_02x((char *)disp_moji, (gRTC_day & 0x3f) );
				disp_lcd_G( 8,1,disp_moji);									//  \
				wtod_02x((char *)disp_moji, (gRTC_hou & 0x3f) );
				disp_lcd_G(11,1,disp_moji);									//  \
				wtod_02x((char *)disp_moji, (gRTC_min & 0x7f) );
				disp_lcd_G(14,1,disp_moji);									//  \
				wtod_02x((char *)disp_moji, (gRTC_sec & 0x7f) );
				disp_lcd_G(17,1,disp_moji);									// b \
				get_pgm_str(&str_save_exit[0]);								// "Save&Exit"
				disp_lcd_G( 0,2,disp_moji);									// \
				get_pgm_str(&str_exit[0]);									// "Exit"
				disp_lcd_G( 0,3,disp_moji);									// \

			}else{															// _ł̖ł̎
				get_pgm_str(&str_space10[0]);								// vÖ̕("      ")擾
				switch(keta){
				 case 0:
					disp_one_char_lcd_G( 2, 1, ' ');						// N̂PǑ
					break;
				 case 1:
					disp_one_char_lcd_G( 3, 1, ' ');						// N̂P̌
					break;
				 case 2:
					disp_one_char_lcd_G( 5, 1, ' ');						// ̂PǑ
					break;
				 case 3:
					disp_one_char_lcd_G( 6, 1, ' ');						// ̂P̌
					break;
				 case 4:
					disp_one_char_lcd_G( 8, 1, ' ');						// ̂PǑ
					break;
				 case 5:
					disp_one_char_lcd_G( 9, 1, ' ');						// ̂P̌
					break;
				 case 6:
					disp_one_char_lcd_G(11, 1, ' ');						// ̂PǑ
					break;
				 case 7:
					disp_one_char_lcd_G(12, 1, ' ');						// ̂P̌
					break;
				 case 8:
					disp_one_char_lcd_G(14, 1, ' ');						// ̂PǑ
					break;
				 case 9:
					disp_one_char_lcd_G(15, 1, ' ');						// ̂P̌
					break;
				 case 10:
					disp_one_char_lcd_G(17, 1, ' ');						// b̂PǑ
					break;
				 case 11:
					disp_one_char_lcd_G(18, 1, ' ');						// b̂P̌
					break;
				 case 12:
					disp_lcd_G ( 0,2, disp_moji);							// "Save&Exit" \
					break;
				 case 13:
					disp_lcd_G ( 0,3, disp_moji);							// "Exit" \
					break;
				}
			}
		}
		get_sw();															//@XCb`Ԃ
		if(sw[2] != 0){														// ꂽXCb`L鎞
			if((sw[2] & SW_LEFT) != 0){										// XCb`
				keta++;
				if(13 < keta){
					keta = 0;
				}
#ifdef		CONFIG_BACK_LIGHT_ON
				start_back_light();											// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
			}else if((sw[2] & SW_RIGHT) != 0){								// EXCb`
#ifdef		CONFIG_BACK_LIGHT_ON
				start_back_light();											// obNCg̎nmX^[gs
#endif		//CONFIG_BACK_LIGHT_ON
				if(keta == 12){												// ۑ&Ȉꏊ
					if((gRTC_mon < 0x01)||(0x12 < gRTC_mon)){				// ̒l
						keta = 3;
					}else if( (gRTC_mon == 2)&&(gRTC_year%4 != 0)&&((gRTC_day < 0x01)||(0x28 < gRTC_day)) ){			// ̒l
						keta = 5;
					}else if( (gRTC_mon == 2)&&(gRTC_year%4 == 0)&&((gRTC_day < 0x01)||(0x29 < gRTC_day)) ){			// ̒l
						keta = 5;
					}else if( ((gRTC_mon == 4)||(gRTC_mon == 6)||(gRTC_mon == 9)||(gRTC_mon == 11))&&((gRTC_day < 0x01)||(0x31 < gRTC_day)) ){			// ̒l
						keta = 5;
					}else if( (gRTC_day < 0x01)||(0x31 < gRTC_day) ){		// ̒l
						keta = 5;
					}else if(0x23 < gRTC_hou){								// ̒l
						keta = 7;
					}else if(0x59 < gRTC_min){								// ̒l
						keta = 9;
					}else if(0x59 < gRTC_sec){								// b̒l
						keta = 11;
					}else{
						r = rtc_write();									// RTC 
						sei();												// 荞݉
						break;
					}
				}else if(keta == 13){										// Ȉꏊ
					break;
				}else{
					switch(keta){
					 case 0:
						if( (gRTC_year & 0xf0) != 0x90 ){					// PǑXȊO̎
							gRTC_year += 0x10;								// N̂PǑ{P
						}else{
							gRTC_year &= 0x0f;								// N̂PǑO
						}
						break;
					 case 1:
						if( (gRTC_year & 0x0f) != 0x09 ){					// P̌XȊO̎
							gRTC_year += 0x01;								// N̂P̌{P
						}else{
							gRTC_year &= 0xf0;								// N̂P̌O
						}
						break;
					 case 2:
						if( (gRTC_mon & 0xf0) != 0x10 ){					// PǑPȊO̎
							gRTC_mon += 0x10;								// ̂PǑ{P
						}else{
							gRTC_mon &= 0x0f;								// ̂PǑO
						}
						break;
					 case 3:
						if( (gRTC_mon & 0x0f) != 0x09 ){					// P̌XȊO̎
							gRTC_mon += 0x01;								// ̂P̌{P
						}else{
							gRTC_mon &= 0xf0;								// ̂P̌O
						}
						break;
					 case 4:
						if( (gRTC_day & 0x30) != 0x30 ){					// PǑRȊO̎
							gRTC_day += 0x10;								// ̂PǑ{P
						}else{
							gRTC_day &= 0x0f;								// ̂PǑO
						}
						break;
					 case 5:
						if( (gRTC_day & 0x0f) != 0x09 ){					// P̌XȊO̎
							gRTC_day += 0x01;								// ̂P̌{P
						}else{
							gRTC_day &= 0xf0;								// ̂P̌O
						}
						break;
					 case 6:
						if( (gRTC_hou & 0x30) != 0x20 ){					// PǑQȊO̎
							gRTC_hou += 0x10;								// ̂PǑ{P
						}else{
							gRTC_hou &= 0x0f;								// ̂PǑO
						}
						break;
					 case 7:
						if( (gRTC_hou & 0x0f) != 0x09 ){					// P̌XȊO̎
							gRTC_hou += 0x01;								// ̂P̌{P
						}else{
							gRTC_hou &= 0xf0;								// ̂P̌O
						}
						break;
					 case 8:
						if( (gRTC_min & 0x70) != 0x50 ){					// PǑTȊO̎
							gRTC_min += 0x10;								// ̂PǑ{P
						}else{
							gRTC_min &= 0x0f;								// ̂PǑO
						}
						break;
					 case 9:
						if( (gRTC_min & 0x0f) != 0x09 ){					// P̌XȊO̎
							gRTC_min += 0x01;								// ̂P̌{P
						}else{
							gRTC_min &= 0xf0;								// ̂P̌O
						}
						break;
					 case 10:
						if( (gRTC_sec & 0x70) != 0x50 ){					// PǑTȊO̎
							gRTC_sec += 0x10;								// b̂PǑ{P
						}else{
							gRTC_sec &= 0x0f;								// b̂PǑO
						}
						break;
					 case 11:
						if( (gRTC_sec & 0x0f) != 0x09 ){					// P̌XȊO̎
							gRTC_sec += 0x01;								// b̂P̌{P
						}else{
							gRTC_sec &= 0xf0;								// b̂P̌O
						}
						break;
					}
				}
				kesu = 1;
				tim_10ms_buz = 0;											// Iɕ\
			}
		}

#ifdef		CONFIG_BACK_LIGHT_ON
		proc_back_light();													// obNCĝnm^nees
#endif		//CONFIG_BACK_LIGHT_ON

	}

	wait_key_off();															// Q̃XCb`Q@܂ŉiv[v

	cli();

	return(r);
}

//*****************************************
// unsigned long ̒lɕϊ
//  ϊl gDate_Time ɂ͓
//*****************************************
void	convert_date_time(void)
{
	unsigned long	ul;

	ul = 0;
	ul += (unsigned long)((gRTC_min & 0x0f)) * 1L;					// 
	ul += (unsigned long)(((gRTC_min >> 4) & 0x0f)) * 10L;			// PO
	ul += (unsigned long)((gRTC_hou & 0x0f)) * 100L;				// 
	ul += (unsigned long)(((gRTC_hou >> 4) & 0x0f)) * 1000L;		// PO
	ul += (unsigned long)((gRTC_day & 0x0f)) * 10000L;				// 
	ul += (unsigned long)(((gRTC_day >> 4) & 0x0f)) * 100000L;		// PO
	ul += (unsigned long)((gRTC_mon & 0x0f)) * 1000000L;			// 
	ul += (unsigned long)(((gRTC_mon >> 4) & 0x0f)) * 10000000L;	// PO
	ul += (unsigned long)((gRTC_year & 0x0f)) * 100000000L;			// N
	ul += (unsigned long)(((gRTC_year >> 4) & 0x0f)) * 1000000000L;	// PON

	gDate_Time = ul;
}

//*****************************************
// unsigned long ̒l\pɕϊ
//  @ϊl
//  ϊl disp_moji ɂ͓
//*****************************************
void	convert_display_date_time(unsigned long ul)
{
	unsigned char	mm[21];

	if((ul == 0xffffffff)||(ul == 0L)){
		get_pgm_str(&str_5minus[0]);									// "-----"
		llstrcpy((char *)mm, (char *)disp_moji);
		llstrcpy((char *)&mm[5], (char *)disp_moji);
		llstrcpy((char *)&mm[10], (char *)disp_moji);
		llstrcpy((char *)&mm[15], (char *)&disp_moji[4]);
	}else{
		wtod_010u((char *)disp_moji, ul);
		mm[0] = '2';
		mm[1] = '0';
		llstrncpy((char *)&mm[2], (char *)&disp_moji[0],2);
		mm[4] = '/';
		llstrncpy((char *)&mm[5], (char *)&disp_moji[2],2);
		mm[7] = '/';
		llstrncpy((char *)&mm[8], (char *)&disp_moji[4],2);
		mm[10] = ' ';
		llstrncpy((char *)&mm[11], (char *)&disp_moji[6],2);
		mm[13] = ':';
		llstrncpy((char *)&mm[14], (char *)&disp_moji[8],2);
		mm[16] = 0;
	}

	llstrcpy((char *)disp_moji, (char *)mm);
}

//*****************************************
// INT0 Interrupt
//  Start Bit Falling Edge Sence
// 	qsb@rpvM
//  \߁@qsb̏ݒłPbo͂ɐݒ肷邱
//*****************************************
ISR (INT0_vect)
{
	gCount_sqw++;								// rpvM̃JEg@{P
	rtc_1s_flg++;								// qsbĂ鎞̂Pboߗp

}
